/* Document history 

4-6-04 - regenerated node table inserts because I had swapped the yesChildId and noChild id fields in the excel file.
	 This was reversing the entire tree.

*/

/* 
The node table holds information about every node in the tree, internal or no.

methodId	- is this a small (1); or large (2); tree node
terminalNodeId	- terminal node id, if this is a terminal node
yesChildId	- nodeId of the yes child, nothing if terminal node
noChildId	- nodeId of the no child, nothing if terminal node
questionId	- the question asked at this node
numBuildings	- number of buildings that meet this node's criteria.
median		- median cost of all the buildings that meet this node's criteria. 
                  (NOTE: this is in 1993 dollars. The application multiplies it by a factor of 1.25283 to bring it up to 
		  2002 dollars before displaying to user.)
*/
create table node
( id INTEGER,
  methodId INTEGER,		
  terminalNodeId INTEGER,	
  yesChildId INTEGER,		
  noChildId INTEGER,
  questionId INTEGER,		
  numBuildings INTEGER,		
  median FLOAT );


/* 
The terminalNode table holds statistics associated with each terminal node.


id		- terminal node id, used as a foreign key in the node table
methodId	- is this a small (1); or large (2); tree node
q1		- first quartile border
q3		- third quartile border
qr		- range between q1 and q3.
		  (NOTE: q3 and q1 are in 1993 dollars. The application multiplies it by a factor of 1.25283 to bring it up to 
		  2002 dollars before displaying to user.)
*/

create table terminalNode
( id INTEGER,
  methodId INTEGER,
  q1 FLOAT,
  q3 FLOAT,
  qr FLOAT );

/* SQL INSERTs created from SQLgenerator.xls spreadsheet */
INSERT INTO node VALUES( 1, 1, 0, 4, 2, 1, 1978, 11.278);
INSERT INTO node VALUES( 2, 1, 0, 3, 20, 2, 195, 27.581);
INSERT INTO node VALUES( 3, 1, 0, 22, 21, 3, 22, 52.69);
INSERT INTO node VALUES( 4, 1, 0, 14, 5, 2, 1783, 10.281);
INSERT INTO node VALUES( 5, 1, 0, 32, 6, 2, 1487, 9.513);
INSERT INTO node VALUES( 6, 1, 0, 31, 7, 4, 1433, 9.845);
INSERT INTO node VALUES( 7, 1, 0, 30, 8, 4, 1245, 9.286);
INSERT INTO node VALUES( 8, 1, 0, 9, 23, 5, 1158, 8.91);
INSERT INTO node VALUES( 9, 1, 0, 29, 10, 1, 1124, 8.554);
INSERT INTO node VALUES( 10, 1, 0, 28, 11, 2, 1005, 9.108);
INSERT INTO node VALUES( 11, 1, 0, 27, 12, 4, 661, 7.957);
INSERT INTO node VALUES( 12, 1, 0, 26, 13, 3, 593, 7.564);
INSERT INTO node VALUES( 13, 1, 0, 25, 24, 4, 148, 10.332);
INSERT INTO node VALUES( 14, 1, 0, 16, 15, 5, 296, 17.188);
INSERT INTO node VALUES( 15, 1, 0, 34, 33, 1, 45, 34.088);
INSERT INTO node VALUES( 16, 1, 0, 39, 17, 4, 251, 16.408);
INSERT INTO node VALUES( 17, 1, 0, 38, 18, 4, 234, 16.719);
INSERT INTO node VALUES( 18, 1, 0, 19, 35, 3, 224, 16.502);
INSERT INTO node VALUES( 19, 1, 0, 37, 36, 4, 83, 24.243);
INSERT INTO node VALUES( 20, 1, 1, 0, 0, 0, 173, 24.948);
INSERT INTO node VALUES( 21, 1, 2, 0, 0, 0, 10, 39.04);
INSERT INTO node VALUES( 22, 1, 3, 0, 0, 0, 12, 73.244);
INSERT INTO node VALUES( 23, 1, 4, 0, 0, 0, 34, 20.637);
INSERT INTO node VALUES( 24, 1, 5, 0, 0, 0, 94, 5.691);
INSERT INTO node VALUES( 25, 1, 6, 0, 0, 0, 54, 19.07);
INSERT INTO node VALUES( 26, 1, 7, 0, 0, 0, 445, 7.115);
INSERT INTO node VALUES( 27, 1, 8, 0, 0, 0, 68, 15.019);
INSERT INTO node VALUES( 28, 1, 9, 0, 0, 0, 344, 11.348);
INSERT INTO node VALUES( 29, 1, 10, 0, 0, 0, 119, 4.762);
INSERT INTO node VALUES( 30, 1, 11, 0, 0, 0, 87, 18.118);
INSERT INTO node VALUES( 31, 1, 12, 0, 0, 0, 188, 14.641);
INSERT INTO node VALUES( 32, 1, 13, 0, 0, 0, 54, 1.795);
INSERT INTO node VALUES( 33, 1, 14, 0, 0, 0, 32, 38.938);
INSERT INTO node VALUES( 34, 1, 15, 0, 0, 0, 13, 17.188);
INSERT INTO node VALUES( 35, 1, 16, 0, 0, 0, 141, 15.563);
INSERT INTO node VALUES( 36, 1, 17, 0, 0, 0, 62, 18.897);
INSERT INTO node VALUES( 37, 1, 18, 0, 0, 0, 21, 39.128);
INSERT INTO node VALUES( 38, 1, 19, 0, 0, 0, 10, 42.85);
INSERT INTO node VALUES( 39, 1, 20, 0, 0, 0, 17, 3.129);
INSERT INTO node VALUES( 1, 2, 0, 11, 2, 1, 1978, 11.278);
INSERT INTO node VALUES( 2, 2, 0, 10, 3, 6, 196, 27.581);
INSERT INTO node VALUES( 3, 2, 0, 63, 4, 2, 167, 24.275);
INSERT INTO node VALUES( 4, 2, 0, 62, 5, 5, 150, 23.819);
INSERT INTO node VALUES( 5, 2, 0, 61, 6, 7, 130, 24.275);
INSERT INTO node VALUES( 6, 2, 0, 60, 7, 8, 114, 26.492);
INSERT INTO node VALUES( 7, 2, 0, 9, 8, 3, 85, 29.793);
INSERT INTO node VALUES( 8, 2, 0, 57, 56, 5, 53, 24.868);
INSERT INTO node VALUES( 9, 2, 0, 59, 58, 9, 32, 39.248);
INSERT INTO node VALUES( 10, 2, 0, 65, 64, 10, 29, 44.95);
INSERT INTO node VALUES( 11, 2, 0, 42, 12, 2, 1782, 10.296);
INSERT INTO node VALUES( 12, 2, 0, 36, 13, 8, 1486, 9.547);
INSERT INTO node VALUES( 13, 2, 0, 32, 14, 4, 1254, 10.296);
INSERT INTO node VALUES( 14, 2, 0, 25, 15, 11, 1082, 9.621);
INSERT INTO node VALUES( 15, 2, 0, 21, 16, 12, 587, 7.903);
INSERT INTO node VALUES( 16, 2, 0, 18, 17, 13, 476, 7.188);
INSERT INTO node VALUES( 17, 2, 0, 67, 66, 5, 358, 6.369);
INSERT INTO node VALUES( 18, 2, 0, 71, 19, 10, 118, 11.791);
INSERT INTO node VALUES( 19, 2, 0, 70, 20, 4, 106, 10.63);
INSERT INTO node VALUES( 20, 2, 0, 69, 68, 14, 96, 12.477);
INSERT INTO node VALUES( 21, 2, 0, 22, 72, 3, 111, 12.469);
INSERT INTO node VALUES( 22, 2, 0, 23, 73, 5, 96, 13.641);
INSERT INTO node VALUES( 23, 2, 0, 76, 24, 1, 63, 11.826);
INSERT INTO node VALUES( 24, 2, 0, 75, 74, 15, 48, 13.641);
INSERT INTO node VALUES( 25, 2, 0, 30, 26, 4, 495, 11.865);
INSERT INTO node VALUES( 26, 2, 0, 29, 27, 4, 374, 10.692);
INSERT INTO node VALUES( 27, 2, 0, 79, 28, 13, 327, 9.589);
INSERT INTO node VALUES( 28, 2, 0, 78, 77, 16, 315, 9.501);
INSERT INTO node VALUES( 29, 2, 0, 81, 80, 1, 47, 21.493);
INSERT INTO node VALUES( 30, 2, 0, 84, 31, 16, 121, 18.161);
INSERT INTO node VALUES( 31, 2, 0, 83, 82, 5, 107, 19.072);
INSERT INTO node VALUES( 32, 2, 0, 89, 33, 17, 172, 15.296);
INSERT INTO node VALUES( 33, 2, 0, 88, 34, 5, 161, 14.767);
INSERT INTO node VALUES( 34, 2, 0, 87, 35, 11, 95, 19.738);
INSERT INTO node VALUES( 35, 2, 0, 86, 85, 1, 35, 26.13);
INSERT INTO node VALUES( 36, 2, 0, 37, 90, 5, 232, 5.002);
INSERT INTO node VALUES( 37, 2, 0, 96, 38, 2, 221, 4.816);
INSERT INTO node VALUES( 38, 2, 0, 95, 39, 12, 196, 5.504);
INSERT INTO node VALUES( 39, 2, 0, 40, 91, 5, 172, 4.993);
INSERT INTO node VALUES( 40, 2, 0, 41, 92, 18, 139, 4.442);
INSERT INTO node VALUES( 41, 2, 0, 94, 93, 19, 20, 11.593);
INSERT INTO node VALUES( 42, 2, 0, 44, 43, 5, 296, 17.188);
INSERT INTO node VALUES( 43, 2, 0, 98, 97, 16, 45, 34.088);
INSERT INTO node VALUES( 44, 2, 0, 111, 45, 20, 251, 16.408);
INSERT INTO node VALUES( 45, 2, 0, 55, 46, 6, 227, 16.876);
INSERT INTO node VALUES( 46, 2, 0, 108, 47, 4, 199, 16.497);
INSERT INTO node VALUES( 47, 2, 0, 107, 48, 11, 189, 16.312);
INSERT INTO node VALUES( 48, 2, 0, 53, 49, 14, 166, 16.502);
INSERT INTO node VALUES( 49, 2, 0, 51, 50, 7, 127, 15.925);
INSERT INTO node VALUES( 50, 2, 0, 100, 99, 19, 33, 19.611);
INSERT INTO node VALUES( 51, 2, 0, 103, 52, 5, 94, 15.127);
INSERT INTO node VALUES( 52, 2, 0, 102, 101, 4, 46, 16.876);
INSERT INTO node VALUES( 53, 2, 0, 106, 54, 21, 39, 24.258);
INSERT INTO node VALUES( 54, 2, 0, 105, 104, 1, 26, 29.574);
INSERT INTO node VALUES( 55, 2, 0, 110, 109, 5, 28, 38.29);
INSERT INTO node VALUES( 56, 2, 1, 0, 0, 0, 11, 33.577);
INSERT INTO node VALUES( 57, 2, 2, 0, 0, 0, 42, 24.171);
INSERT INTO node VALUES( 58, 2, 3, 0, 0, 0, 15, 58.331);
INSERT INTO node VALUES( 59, 2, 4, 0, 0, 0, 17, 30.252);
INSERT INTO node VALUES( 60, 2, 5, 0, 0, 0, 29, 20.165);
INSERT INTO node VALUES( 61, 2, 6, 0, 0, 0, 16, 11.131);
INSERT INTO node VALUES( 62, 2, 7, 0, 0, 0, 20, 7.565);
INSERT INTO node VALUES( 63, 2, 8, 0, 0, 0, 17, 52.69);
INSERT INTO node VALUES( 64, 2, 9, 0, 0, 0, 16, 65.984);
INSERT INTO node VALUES( 65, 2, 10, 0, 0, 0, 13, 33.824);
INSERT INTO node VALUES( 66, 2, 11, 0, 0, 0, 92, 9.547);
INSERT INTO node VALUES( 67, 2, 12, 0, 0, 0, 266, 5.688);
INSERT INTO node VALUES( 68, 2, 13, 0, 0, 0, 13, 2.72);
INSERT INTO node VALUES( 69, 2, 14, 0, 0, 0, 83, 13.28);
INSERT INTO node VALUES( 70, 2, 15, 0, 0, 0, 10, 2.159);
INSERT INTO node VALUES( 71, 2, 16, 0, 0, 0, 12, 30.039);
INSERT INTO node VALUES( 72, 2, 17, 0, 0, 0, 15, 5.138);
INSERT INTO node VALUES( 73, 2, 18, 0, 0, 0, 33, 19.005);
INSERT INTO node VALUES( 74, 2, 19, 0, 0, 0, 36, 12.723);
INSERT INTO node VALUES( 75, 2, 20, 0, 0, 0, 12, 24.948);
INSERT INTO node VALUES( 76, 2, 21, 0, 0, 0, 15, 5.375);
INSERT INTO node VALUES( 77, 2, 22, 0, 0, 0, 74, 5.715);
INSERT INTO node VALUES( 78, 2, 23, 0, 0, 0, 241, 10.521);
INSERT INTO node VALUES( 79, 2, 24, 0, 0, 0, 12, 31.965);
INSERT INTO node VALUES( 80, 2, 25, 0, 0, 0, 11, 38.961);
INSERT INTO node VALUES( 81, 2, 26, 0, 0, 0, 36, 17.82);
INSERT INTO node VALUES( 82, 2, 27, 0, 0, 0, 18, 38.14);
INSERT INTO node VALUES( 83, 2, 28, 0, 0, 0, 89, 18.226);
INSERT INTO node VALUES( 84, 2, 29, 0, 0, 0, 14, 8.259);
INSERT INTO node VALUES( 85, 2, 30, 0, 0, 0, 25, 21.649);
INSERT INTO node VALUES( 86, 2, 31, 0, 0, 0, 10, 34.832);
INSERT INTO node VALUES( 87, 2, 32, 0, 0, 0, 60, 15.511);
INSERT INTO node VALUES( 88, 2, 33, 0, 0, 0, 66, 12.042);
INSERT INTO node VALUES( 89, 2, 34, 0, 0, 0, 11, 35.494);
INSERT INTO node VALUES( 90, 2, 35, 0, 0, 0, 11, 20.637);
INSERT INTO node VALUES( 91, 2, 36, 0, 0, 0, 33, 7.957);
INSERT INTO node VALUES( 92, 2, 37, 0, 0, 0, 119, 4.133);
INSERT INTO node VALUES( 93, 2, 38, 0, 0, 0, 10, 5.002);
INSERT INTO node VALUES( 94, 2, 39, 0, 0, 0, 10, 24.462);
INSERT INTO node VALUES( 95, 2, 40, 0, 0, 0, 24, 12.69);
INSERT INTO node VALUES( 96, 2, 41, 0, 0, 0, 25, 0.924);
INSERT INTO node VALUES( 97, 2, 42, 0, 0, 0, 15, 9.845);
INSERT INTO node VALUES( 98, 2, 43, 0, 0, 0, 30, 39.801);
INSERT INTO node VALUES( 99, 2, 44, 0, 0, 0, 21, 23.01);
INSERT INTO node VALUES( 100, 2, 45, 0, 0, 0, 12, 14.788);
INSERT INTO node VALUES( 101, 2, 46, 0, 0, 0, 34, 16.629);
INSERT INTO node VALUES( 102, 2, 47, 0, 0, 0, 12, 30.316);
INSERT INTO node VALUES( 103, 2, 48, 0, 0, 0, 48, 8.813);
INSERT INTO node VALUES( 104, 2, 49, 0, 0, 0, 11, 35.712);
INSERT INTO node VALUES( 105, 2, 50, 0, 0, 0, 15, 22.283);
INSERT INTO node VALUES( 106, 2, 51, 0, 0, 0, 13, 16.482);
INSERT INTO node VALUES( 107, 2, 52, 0, 0, 0, 23, 8.399);
INSERT INTO node VALUES( 108, 2, 53, 0, 0, 0, 10, 42.85);
INSERT INTO node VALUES( 109, 2, 54, 0, 0, 0, 17, 58.933);
INSERT INTO node VALUES( 110, 2, 55, 0, 0, 0, 11, 11.839);
INSERT INTO node VALUES( 111, 2, 56, 0, 0, 0, 24, 4.87);

INSERT INTO terminalNode VALUES( 1, 1, 13.88, 40.85, 2.9425);
INSERT INTO terminalNode VALUES( 2, 1, 15.11, 49.01, 3.2437);
INSERT INTO terminalNode VALUES( 3, 1, 48.82, 96.05, 1.9675);
INSERT INTO terminalNode VALUES( 4, 1, 13.5, 32.57, 2.4126);
INSERT INTO terminalNode VALUES( 5, 1, 2.15, 11.09, 5.1382);
INSERT INTO terminalNode VALUES( 6, 1, 12.55, 24.95, 1.9874);
INSERT INTO terminalNode VALUES( 7, 1, 4.36, 11.59, 2.6598);
INSERT INTO terminalNode VALUES( 8, 1, 8.47, 26.89, 3.1733);
INSERT INTO terminalNode VALUES( 9, 1, 5.79, 20.73, 3.5802);
INSERT INTO terminalNode VALUES( 10, 1, 2.24, 9.83, 4.3866);
INSERT INTO terminalNode VALUES( 11, 1, 9.81, 23.55, 2.4001);
INSERT INTO terminalNode VALUES( 12, 1, 8.08, 27.33, 3.3807);
INSERT INTO terminalNode VALUES( 13, 1, 0.73, 4.3, 5.8819);
INSERT INTO terminalNode VALUES( 14, 1, 30.81, 52.5, 1.7042);
INSERT INTO terminalNode VALUES( 15, 1, 6.94, 26.8, 3.8613);
INSERT INTO terminalNode VALUES( 16, 1, 8.81, 22.06, 2.504);
INSERT INTO terminalNode VALUES( 17, 1, 7.34, 38.56, 5.2541);
INSERT INTO terminalNode VALUES( 18, 1, 34.22, 59.67, 1.7439);
INSERT INTO terminalNode VALUES( 19, 1, 24.61, 82.54, 3.3539);
INSERT INTO terminalNode VALUES( 20, 1, 2.06, 6.89, 3.3402);
INSERT INTO terminalNode VALUES( 1, 2, 24.8679, 39.5892, 1.592);
INSERT INTO terminalNode VALUES( 2, 2, 19.3579, 37.0432, 1.9136);
INSERT INTO terminalNode VALUES( 3, 2, 36.526, 71.1306, 1.9474);
INSERT INTO terminalNode VALUES( 4, 2, 19.7254, 39.2478, 1.9897);
INSERT INTO terminalNode VALUES( 5, 2, 9.4002, 32.0708, 3.4117);
INSERT INTO terminalNode VALUES( 6, 2, 2.7665, 17.2031, 6.2184);
INSERT INTO terminalNode VALUES( 7, 2, 1.7247, 26.4191, 15.3177);
INSERT INTO terminalNode VALUES( 8, 2, 29.2096, 73.2435, 2.5075);
INSERT INTO terminalNode VALUES( 9, 2, 45.9144, 80.0081, 1.7425);
INSERT INTO terminalNode VALUES( 10, 2, 24.6248, 43.3446, 1.7602);
INSERT INTO terminalNode VALUES( 11, 2, 6.6484, 14.3288, 2.1552);
INSERT INTO terminalNode VALUES( 12, 2, 3.6204, 8.1651, 2.2553);
INSERT INTO terminalNode VALUES( 13, 2, 2.268, 8.5347, 3.7632);
INSERT INTO terminalNode VALUES( 14, 2, 7.9117, 24.1234, 3.0491);
INSERT INTO terminalNode VALUES( 15, 2, 1.2602, 8.2089, 6.5138);
INSERT INTO terminalNode VALUES( 16, 2, 12.6859, 40.0572, 3.1576);
INSERT INTO terminalNode VALUES( 17, 2, 2.5039, 7.2403, 2.8916);
INSERT INTO terminalNode VALUES( 18, 2, 12.464, 35.0233, 2.81);
INSERT INTO terminalNode VALUES( 19, 2, 8.0045, 17.8165, 2.2258);
INSERT INTO terminalNode VALUES( 20, 2, 15.707, 27.8443, 1.7727);
INSERT INTO terminalNode VALUES( 21, 2, 3.5478, 9.8593, 2.779);
INSERT INTO terminalNode VALUES( 22, 2, 2.6228, 12.6463, 4.8217);
INSERT INTO terminalNode VALUES( 23, 2, 5.2904, 16.9118, 3.1967);
INSERT INTO terminalNode VALUES( 24, 2, 6.8689, 42.3469, 6.165);
INSERT INTO terminalNode VALUES( 25, 2, 24.0065, 53.3374, 2.2218);
INSERT INTO terminalNode VALUES( 26, 2, 11.0866, 22.2752, 2.0092);
INSERT INTO terminalNode VALUES( 27, 2, 20.6063, 47.5965, 2.3098);
INSERT INTO terminalNode VALUES( 28, 2, 11.5615, 24.4421, 2.1141);
INSERT INTO terminalNode VALUES( 29, 2, 5.9601, 9.8563, 1.6537);
INSERT INTO terminalNode VALUES( 30, 2, 14.7672, 29.4823, 1.9965);
INSERT INTO terminalNode VALUES( 31, 2, 30.0786, 39.2881, 1.3062);
INSERT INTO terminalNode VALUES( 32, 2, 9.4944, 22.0661, 2.3241);
INSERT INTO terminalNode VALUES( 33, 2, 7.0847, 21.1169, 2.9806);
INSERT INTO terminalNode VALUES( 34, 2, 24.0527, 45.5544, 1.8939);
INSERT INTO terminalNode VALUES( 35, 2, 15.4637, 39.4618, 2.5519);
INSERT INTO terminalNode VALUES( 36, 2, 5.5041, 10.4167, 1.8925);
INSERT INTO terminalNode VALUES( 37, 2, 1.8724, 8.2655, 4.4143);
INSERT INTO terminalNode VALUES( 38, 2, 2.24, 6.6833, 2.9836);
INSERT INTO terminalNode VALUES( 39, 2, 13.6607, 48.1607, 3.5255);
INSERT INTO terminalNode VALUES( 40, 2, 5.1871, 19.4405, 3.7479);
INSERT INTO terminalNode VALUES( 41, 2, 0.4515, 1.8642, 4.1289);
INSERT INTO terminalNode VALUES( 42, 2, 6.9406, 21.5159, 3.1);
INSERT INTO terminalNode VALUES( 43, 2, 33.9664, 53.4351, 1.5732);
INSERT INTO terminalNode VALUES( 44, 2, 19.1063, 23.0115, 1.2044);
INSERT INTO terminalNode VALUES( 45, 2, 2.9342, 16.1939, 5.519);
INSERT INTO terminalNode VALUES( 46, 2, 15.1466, 18.1915, 1.201);
INSERT INTO terminalNode VALUES( 47, 2, 18.0272, 45.0342, 2.4981);
INSERT INTO terminalNode VALUES( 48, 2, 5.3677, 15.0643, 2.8065);
INSERT INTO terminalNode VALUES( 49, 2, 27.9343, 77.438, 2.7721);
INSERT INTO terminalNode VALUES( 50, 2, 10.5785, 31.6378, 2.9908);
INSERT INTO terminalNode VALUES( 51, 2, 12.8789, 28.442, 2.2084);
INSERT INTO terminalNode VALUES( 52, 2, 4.3379, 17.8104, 4.1058);
INSERT INTO terminalNode VALUES( 53, 2, 24.6099, 82.5389, 3.3539);
INSERT INTO terminalNode VALUES( 54, 2, 31.0478, 63.3971, 2.0419);
INSERT INTO terminalNode VALUES( 55, 2, 8.2765, 40.0775, 4.8423);
INSERT INTO terminalNode VALUES( 56, 2, 2.126, 7.5466, 3.5497);