/**
 * 
 * PoolManager provides database pool intercation functionality.
 */


package gov.fema.web.srce;

import gov.fema.jdbc.pool.ApacheDBCPConnectionPool;

import java.sql.Connection;

import org.apache.log4j.Logger;

/**
 * 
 * Copied straight the FEMA specification.
 * 
 * Pool Manager is a class that provides database connectivity for the applications.
 * 
 * @author Neil Chilson
 */
public class PoolManager {

    private static ApacheDBCPConnectionPool connectionPool = null;

    protected static final Logger logger = Logger.getLogger(PoolManager.class.getName());

    /**
     * Initializes the pool using the name of the config file and the name of the pool
     * passed in
     *
     * @param		poolConfig			the name of the config file
     * @throws		Exception
     */
    public static void init(   String poolConfig) throws Exception {
        if (connectionPool == null) {
        	connectionPool = new ApacheDBCPConnectionPool(poolConfig);
        }
    }
    
    /**
     * Gets connection from the pool 
     *
     * @return		Connection			a Connection object
     * @throws		Exception
     */
	public static Connection getConnection() throws Exception {
        return connectionPool.getConnection();
	}
	
	/**
	 * Shuts down the pool 
	 *
	 */
	 public static void destroy() {
	     if (connectionPool != null) {
	         try {
	             connectionPool.getDataSource().close();
	         } catch (Exception ex) {
	             // Don't worry much about exceptions, since we're closing anyway.  But we'll log just in case.
	             logger.fatal(ex.getMessage());
	         }
	         connectionPool = null;
	     }
	 }
	
}
