/*
 * Created on Feb 19, 2004
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package gov.fema.web.srce;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

import gov.fema.web.srce.objects.Answer;
import gov.fema.web.srce.objects.Answers;
import gov.fema.web.srce.objects.DecisionNode;
import gov.fema.web.srce.objects.DecisionTree;
import gov.fema.web.srce.objects.ExpertDecisionTree;
import gov.fema.web.srce.objects.Question;
import gov.fema.web.srce.objects.TerminalNode;
import gov.fema.web.srce.objects.TreeNode;
import gov.fema.web.srce.util.DbUtil;

/**
 * Follows the Builder pattern to create the four types of decision trees
 *
 * @author Neil Chilson 
 */
public class TreeManager extends  BaseManager {

	protected static final Logger logger = org.apache.log4j.Logger.getLogger(TreeManager.class);
	
	/**
	 * Default constructor
	 */
	public TreeManager()
	{
		super();
	}
	
	// This method assembles the nodes of a tree over the course of several database calls.
	// Then, the tree is created, the nodes inserted, and the whole thing returned.
	public DecisionTree createStandardModeTree(String method) 
	{
		Connection conn = null;
		DecisionTree tree = null;
		
		try {
			conn = getConnection();
			
			Map nodes = new HashMap();
			String error = getStandardModeNodes(method, nodes, conn);
			if (error != "")
			{
				logger.error("ERROR in createStandardModeTree: " + error);
				return null;
			}
			error = getTerminalNodes(method, nodes, conn);
			if (error != "")
			{
				logger.error("ERROR in createStandardModeTree: " + error);
				return null;
			}
			
			error = assembleNodes(method, nodes, conn);
			if (error != "")
			{
				logger.error("ERROR in createStandardModeTree: " + error);
				return null;
			}
						
			// initialize and return tree
			TreeNode root = (TreeNode) nodes.get(new Integer(1));
			tree = new DecisionTree(method, root, nodes);
		}
		catch(Exception ex) {
			// ex.printStackTrace();
			// error = "ERROR in createStandardModeTree(): " + ex.getMessage();
			logger.error(ex);
		}
		finally {
			DbUtil.cleanup(conn, null, null);
		}
		
		return tree;
	}
	
	// This method assembles the nodes of a tree over the course of several database calls.
	// Then, the tree is created, the nodes inserted, and the whole thig returned.
	/**
	 * This method assembles the nodes of a tree over the course of several database calls.
	 * Then, the tree object is created, the nodes inserted, and the whole thing returned.
	 * 
	 * @param method  	which type of tree to create
	 * @return 			a decision tree
	 */
	public DecisionTree createExpertModeTree(String method) 
	{
		Connection conn = null;
		DecisionTree tree = null;
			
		try {
			conn = getConnection();
			
			Map nodes = new HashMap();
			String error = getExpertModeNodes(method, nodes, conn);
			if (error != "")
			{
				logger.error("ERROR in createStandardModeTree: " + error);
				return null;
			 }
			 
			error = getTerminalNodes(method, nodes, conn);
			if (error != "")
			{
				logger.error("ERROR in createStandardModeTree: " + error);
				return null;
			}
			
			error = assembleNodes(method, nodes, conn);
			if (error != "")
			{
				logger.error("ERROR in createStandardModeTree: " + error);
				return null;
			}
			
			// initialize and return tree
			TreeNode root = (TreeNode) nodes.get(new Integer(1));
			tree = new ExpertDecisionTree(method, root, nodes);
		}
		catch(Exception ex) {
			//ex.printStackTrace();
			//error = "ERROR in createStandardModeTree(): " + ex.getMessage();
			logger.error(ex);
		}
		finally {
			DbUtil.cleanup(conn, null, null);
		}

		return tree;
	}
			
	/**
	 * @param method	what type of tree to build	
	 * @param nodes   	this parameter is filled with the nodes for the tree
	 * @return			an error string, empty if none
	 */
	private String getStandardModeNodes(String method, Map nodes, Connection myConnection)
	{	
		String error = "";
		Statement stmt = null;
		ResultSet rs = null;
		
		String query="";
		
		logger.debug("in getStandardModeNodes");
		
		if (method.equals(DecisionTree.METHOD_1) ||
			method.equals(DecisionTree.METHOD_2))
		{
			query = "SELECT node.id, question.name AS questionName, yesAnswer, noAnswer, median, numBuildings FROM  node, question, standardModeAnswer WHERE node.id=standardModeAnswer.nodeId AND question.id=node.questionId AND node.methodId=" + method + " AND standardModeAnswer.methodId=" + method;
		}
		else
		{
			error = "ERROR in getStandardModeNodes(): Unknown Method: " + method + ".";
			return error;
		}
		
		try
		{
			stmt = myConnection.createStatement();
	
			logger.debug("About to execute : " + query);
			rs = stmt.executeQuery(query);
			logger.debug("Successful Execution of query");
			
			
			if (rs.next()) {
				logger.debug("Parsing results");
				error = parseRSIntoStandardModeNodes(rs, nodes);
				logger.debug("Finished parsing results");
			}
			else
			{
				error = "No Results from query.";
			}
		}
		catch(SQLException e) {
			logger.error(e);
			error = "SQL ERROR in getStandardModeNodes(): " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, stmt, rs);
		}
		
				
		if (error != "")
		{
			logger.error("ERROR in getStandardModeNodes(): "+ error);
		}

		logger.error("Leaving getStandardModeNodes()");

		return error;
	}
	
	/**
	 * @param method	which tree we are building
	 * @param nodes		this parameter is filled with the nodes for the tree
	 * @return			error message; empty if no errors
	 */
	private String getExpertModeNodes(String method, Map nodes, Connection myConnection)
	{	
		String error = "";
		ResultSet rs = null;
		Statement stmt = null;
	
		String query="";
	
		if (method.equals(DecisionTree.METHOD_1) ||
			method.equals(DecisionTree.METHOD_2))
		{
			query = "SELECT node.id, question.name AS questionName, median, numBuildings FROM  node, question WHERE question.id=node.questionId AND node.methodId=" + method;
		}
		else
		{
			error = "ERROR in getExpertModeNodes(): Unknown Method: " + method + ".";
			return error;
		}
	
		try{
			stmt = myConnection.createStatement();
	
			logger.debug("About to execute : " + query);
			rs = stmt.executeQuery(query);
			logger.debug("Successful Execution of query");
				
			if (rs.next()) {
				logger.debug("Parsing results");
				error = parseRSIntoExpertModeNodes(method, rs, nodes, myConnection);
				logger.debug("Finished parsing results");
			}
			else
			{
				error = "No Results from query.";
			}
		}
		catch(SQLException e) {
			logger.error(e);
			error = "SQL ERROR in getExpertModeNodes(): " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, stmt, rs);
		}
			
		if (error != "")
		{
			logger.error("ERROR in getStandardModeNodes(): "+ error);
		}

		return error;
	}
	
	/**
	 * @param rs		the result set to parse
	 * @param nodes		<code>Map</code> to fill with nodes
	 */
	private String parseRSIntoStandardModeNodes(ResultSet rs, Map nodes) throws SQLException
	{	
		String error = "";
		DecisionNode node;
		
		int id;
		String questionName;
		String yesAnswer;
		String noAnswer;
		int numBuildings;
		double median;
	
		try
		{
		
			do{
				id = rs.getInt("id");
				questionName =  StringUtils.trimToEmpty(rs.getString("questionName"));
				numBuildings = rs.getInt("numBuildings");
				median = rs.getFloat("median");
				yesAnswer = StringUtils.trimToEmpty(rs.getString("yesAnswer"));
				noAnswer = StringUtils.trimToEmpty(rs.getString("noAnswer"));
				
				logger.debug( "Adding node " + id );
				
				// Question.createQuestion(questionName),
				
				node = new DecisionNode(	id, 
											Question.createQuestion(questionName),
											yesAnswer, 
											noAnswer, 
											numBuildings, 
											median * SRCEConstants.FACTOR_2002);
				nodes.put(new Integer(id), node);
						
			} while (rs.next());
		}
		catch (SQLException e) {
			logger.error(e);
			error = "SQL ERROR in parseRSIntoStandardModeNodes(): " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, null, rs);			
		}
		
		return error;
	}
	
	/**
	 * @param rs		result set to parse
	 * @param nodes		<code>Map</code> to fill with nodes
	 */
	private String parseRSIntoExpertModeNodes(String method, ResultSet rs, Map nodes, Connection myConnection)
	{	
		String error = "";
		DecisionNode node;
	
		int id;
		String questionName;
		int numBuildings;
		double median;
		Answers answers;
		
		try
		{		
			do{
				id = rs.getInt("id");
				questionName = StringUtils.trimToEmpty(rs.getString("questionName"));
				numBuildings = rs.getInt("numBuildings");
				median = rs.getFloat("median");
				answers = getAnswersForExpertNode(method, id, myConnection);
					
				logger.debug( "Adding node " + id );
		
				node = new DecisionNode(	id, 
											Question.createQuestion(questionName), 
											answers,
											numBuildings, 
											median * SRCEConstants.FACTOR_2002);
	
				nodes.put(new Integer(id), node);
					
			} while (rs.next());

		}
		catch(SQLException e) {
			logger.error(e);
			error = "SQL ERROR in parseRSIntoExpertModeNodes(): " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, null, rs);			
		}

		return error;
	}
	
	
	/**
	 * @param id	node to get answers for
	 * @return		<code>Answers</code> object filled with the possible answers for this node
	 */
	private Answers getAnswersForExpertNode(String method, int nodeId, Connection myConnection) throws SQLException
	{
		String error = "";
		Statement stmt = null; 
		ResultSet rs = null;
		Answers answers = null;
		String query="";
			
		if (method.equals(DecisionTree.METHOD_1) ||
			method.equals(DecisionTree.METHOD_2))
		{
			query = "SELECT multiChoiceAnswer.text, yesAnswer FROM node, multiChoiceAnswer, nodeMultiChoiceAnswerIntersect WHERE node.id="+ nodeId + " AND node.id=nodeMultiChoiceAnswerIntersect.nodeId AND node.methodId=" + method + " AND nodeMultiChoiceAnswerIntersect.methodId=" + method + " AND nodeMultiChoiceAnswerIntersect.answerid = multiChoiceAnswer.id ORDER BY nodeMultiChoiceAnswerIntersect.sortOrder";
		}
		else
		{
			error = "ERROR in getAnswersForExpertNode(): Unknown Method: " + method + ".";
			logger.error(error);
			return null;
		}
	
		try
		{
			stmt = myConnection.createStatement();
		
			logger.debug("About to execute : " + query);
			rs = stmt.executeQuery(query);
			logger.debug("Successful Execution of query");
			
			if (rs.next()) {
				logger.debug("Parsing results");
				answers = new Answers();
				error = parseRSIntoAnswers(rs, answers);
				logger.debug("Finished parsing results");
			}
			else
			{
				error = "No Results from query.";
			}
		}
		catch(SQLException e) {
			logger.error(e);
			error = "SQL ERROR: " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, stmt, rs);
		}
					
		if (error != "")
		{
			logger.error("ERROR in getAnswersForExpertNode(): "+ error);
		}

		return answers;
	}

	/**
	 * @param rs		result set to parse
	 * @param answers	<code>Answers</code> object to fill 
	 * @return			error string; empty if no errors
	 */
	private String parseRSIntoAnswers(ResultSet rs, Answers answers) 
	{
		String error= "";
			
		String text;
		int isYesAnswer;
		try 
		{
			do{
				text = StringUtils.trimToEmpty(rs.getString("text"));
				isYesAnswer = rs.getInt("yesAnswer");
				
				Answer answer = new Answer(text);
				
				logger.debug( "Adding answer " + answer.getText() );
				if (isYesAnswer == 1) 
				{
					answers.addPossibleAnswer(answer);
					answers.addYesAnswer(answer);
				}
				else
				{
					answers.addPossibleAnswer(answer);
				}			
							
			} while (rs.next());
		}
		catch(SQLException e) {
			logger.error(e);
			error = "SQL ERROR in parseRSIntoAnswers(): " + e.getMessage();
		}
		
		return error;
	}

	/**
	 * @param method	which tree being built
	 * @param nodes		this parameter is filled with the nodes for the tree.
	 * @return			error message; empty if none
	 */
	private String getTerminalNodes(String method, Map nodes, Connection myConnection)
	{	
		String error = "";
		Statement stmt = null;
		ResultSet rs = null;
		
		String query="";
				
		if (method.equals(DecisionTree.METHOD_1) ||
			method.equals(DecisionTree.METHOD_2) )
		{
			query = "SELECT node.id, terminalNode.id AS terminalId, median, numBuildings, q1, q3, qr FROM  node, terminalNode WHERE node.terminalNodeId=terminalNode.id AND node.methodId=" + method + " and terminalNode.methodId=" + method;
		}
		else
		{
			error = "Unknown Method: " + method + ".";
		}
		
		try{
			stmt = myConnection.createStatement();
		
			logger.debug("About to execute : " + query);
			rs = stmt.executeQuery(query);
			logger.debug("Successful Execution of query");
			
			if (rs.next()) {
				logger.debug("Parsing results");
				parseRSIntoTerminalNodes(rs, nodes);
				logger.debug("Finished parsing results");
			}
			else 
			{
				error = "Terminal nodes could not be loaded from the database.";
			}
		}
		catch(SQLException e) {
			logger.error(e);
			error = "SQL ERROR in getTerminalNodes(): " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, stmt, rs);
		}
	
		if (error != "")
		{
			logger.error("ERROR: "+ error);
		}

		return error;
	}


	/**
	 * @param rs		result set to parse
	 * @param nodes		<code>Map</code> of terminal nodes to fill
	 */
	private void parseRSIntoTerminalNodes(ResultSet rs, Map nodes) throws SQLException
	{
		TerminalNode node;
			
		int id;
		int terminalId;
		int numBuildings;
		double median;
		double q1;
		double q3;
		double qr;
		
		do{
			id = rs.getInt("id");
			terminalId = rs.getInt("terminalId");
			numBuildings = rs.getInt("numBuildings");
			// need to bring these values up to 2002 dollars
			median = rs.getFloat("median")  * SRCEConstants.FACTOR_2002;
			q1 = rs.getFloat("q1")  * SRCEConstants.FACTOR_2002;
			q3 = rs.getFloat("q3")  * SRCEConstants.FACTOR_2002;
			// qr is not factored because it is the difference between q1 and q3.
			qr = rs.getFloat("qr");
			
			logger.debug( "Adding node " + id );
			
			node = new TerminalNode( id, terminalId, numBuildings, median, q1, q3, qr );  

			nodes.put(new Integer(id), node);
						
		} while (rs.next());
		
	}
	
	/**
	 * @param method	which tree is being built
	 * @param nodes		<code>Map</code> of nodes to fill
	 * @return			error message; empty if none.
	 */
	private String assembleNodes(String method, Map nodes, Connection myConnection) 
	{
		String error = "";
		Statement stmt = null;
		ResultSet rs = null;
		
		String query="";
		
		if (method.equals(DecisionTree.METHOD_1))
		{
			query = "SELECT node.id, yesChildId, noChildId FROM node WHERE node.methodId=1 AND (NOT yesChildId=0) AND (NOT noChildId=0)";
		}
		else if (method.equals(DecisionTree.METHOD_2))
		{
			query = "SELECT node.id, yesChildId, noChildId FROM node WHERE node.methodId=2 AND (NOT yesChildId=0) AND (NOT noChildId=0)";
		}
		else
		{
			error = "Unknown Method: " + method + ".";
		}
		
		try
		{
			stmt = myConnection.createStatement();
		
			logger.debug("About to execute : " + query);
			rs = stmt.executeQuery(query);
			logger.debug("Successful Execution of query");
			
			if (rs.next()) {
				parseRSIntoNodeConnections(rs, nodes);
			}
			else 
			{
				error = "Internal nodes of the decision tree could not be loaded from the database.";
			}
		}
		catch(SQLException e) 
		{
			error = "SQL ERROR in assembleNodes(): " + e.getMessage();
		}
		finally {
			DbUtil.cleanup(null, stmt, rs);
		}
		
		if (error != "")
		{
			logger.error("ERROR: "+ error);
		}

		return error;
	}

	/**
	 * @param rs		result set to parse
	 * @param nodes		nodes
	 */
	private void parseRSIntoNodeConnections(ResultSet rs, Map nodes) throws SQLException 
	{
		DecisionNode node;
		TreeNode yesChild;
		TreeNode noChild;
		
		int id;
		int yesChildId;
		int noChildId;
				
		logger.debug("Parsing results");
				
		do{
			id = rs.getInt("id");
			yesChildId = rs.getInt("yesChildId");
			noChildId = rs.getInt("noChildId");
								
			logger.debug( "Adding children to node " + id + " yesChild="+ yesChildId + " noChild =" + noChildId );
			
			// Note - this cast could fail if query gets any TerminalNodes. 
			// A correctly written query will retrieve only DecisionNodes. 	
			node = (DecisionNode) nodes.get(new Integer(id));  
			yesChild = (TreeNode) nodes.get(new Integer(yesChildId));
			noChild = (TreeNode) nodes.get(new Integer(noChildId));
			
			node.setYesChild(yesChild);
			node.setNoChild(noChild);
								
		} while (rs.next());
		
		logger.debug("Finished parsing results");
	}
}
