/*
 * Created on Jul 10, 2003
 *
 */
package gov.fema.web.srce.objects;

import org.apache.log4j.Logger;

/**
 * This class wraps the <tt>String</tt> class to allow the 
 * use of a constant <tt>Unknown</tt>
 * @author n-chilson
 */
public class Answer{

	protected static final Logger logger = org.apache.log4j.Logger.getLogger(Answer.class);
	
	private String text;
		
	/**
	 * Creates and returns an "unknown" answer
	 * 
	 * @return The unknown answer.
	 */
	static public Answer Unknown()
	{
		return new Answer("unknown");
	}
		
	/**
	 * Default Constructor
	 */
	public Answer()
	{
		text="";
	}
	
	/**
	 * @param text - The text of the answer.
	 */
	public Answer(String text)
	{
		this.text = text;
	}
	
	/**
	 * @return The current answer text.	 
	 */
	public String getText() {
		return text;
	}
	
	/**
	 * @param text The new answer text.
	 */
	public void setText(String text) {
		this.text = text;
	}

	/** 
	 * Properly compares two Answers by matching their text.
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object obj) 
	{
		logger.debug("In Answer.equals(). Comparing to " + text );
		return (obj instanceof Answer 
				&&  text.equals(((Answer) obj).getText()));
	}

	/**
	 * Should be implemented when using in a Map.
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return text.hashCode();
	}

	/**
	 * Converts to a piece of text.
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return text;
	}

}
