/*
 * Created on Aug 22, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package gov.fema.web.srce.objects;

import java.util.Iterator;
import java.util.NoSuchElementException;
import java.util.Vector;

/**
 * Wraps <tt>Vector</tt> to simplify distinguishing between
 * possible answers and yes answers. Each <tt>DecisionNode</tt> 
 * contains one of these objects and uses it to match answers
 * to decide which way to go.
 * 
 * @author n-chilson
 */
public class Answers{
	
	private Vector possibleAnswers;
	private Vector yesAnswers;

	/**
	 *  Default Constructor
	 */
	public Answers() 
	{
		possibleAnswers = new Vector();	
		yesAnswers = new Vector();
	}

	/**
	 * Constructor for questions with only one yes answer and one no answer (standard mode).
	 * 
	 * @param yesAnswer A single yes answer
	 * @param noAnswer A single no answer. 
	 */
	public Answers(Answer yesAnswer, Answer noAnswer) 
	{
		possibleAnswers = new Vector();	
		possibleAnswers.add(noAnswer);
		possibleAnswers.add(yesAnswer);
		
		yesAnswers = new Vector();
		yesAnswers.add(yesAnswer);
	}

	/**
	 * Constructor for questions with only one yes answer.
	 * 
	 * @param possibleAnswers Vector of all valid answers
	 * @param yesAnswer A single valid answer that is the only 
	 * 					yes answer. 
	 */
	public Answers(Vector possibleAnswers, Answer yesAnswer)
	{
		this.possibleAnswers = possibleAnswers;
		
		Vector newYesAnswers = new Vector();
		newYesAnswers.add(yesAnswer);
		
		setYesAnswers(newYesAnswers);
	}

	/**
	 * Constructor for questions with multiple yes answers.
	 * 
	 * @param possibleAnswers Vector of valid answers
	 * @param yesAnswers      Vector of valid answers that are 
	 * 						  also yes answers
	 */
	public Answers(Vector possibleAnswers, Vector yesAnswers)
	{
		this.possibleAnswers = possibleAnswers;
			
		setYesAnswers(yesAnswers);
	}
	
	/**
	 * Adds possibleAnswer to the collection of possible answers
	 * 
	 * @param possibleAnswer New answer to add
	 */
	public void addPossibleAnswer(Answer possibleAnswer)
	{
		possibleAnswers.add(possibleAnswer);
	}
	
	/**
	 * Adds yesAnswer to the collection of yesAnswers
	 * 
	 * @param yesAnswer Yes answer to add
	 */
	public void addYesAnswer(Answer yesAnswer)
	{
		if( possibleAnswers.contains(yesAnswer) )
		{
			this.yesAnswers.add(yesAnswer);
		}
		else
		{
			throw new NoSuchElementException("The given yes answer " + yesAnswer.getText() + " is not a possible answer.");		
		}
	}
	
	/**
	 * @return A <tt>Vector</tt> containing all the possible answers 
	 */	
	public Vector getPossibleAnswers() {
		return possibleAnswers;
	}

	/**
	 * @return A <tt>Vector</tt> containing all the yes answers
	 */
	public Vector getYesAnswers() {
		return yesAnswers;
	}
	
	/**
	 * Clears yesAnswer and adds new yes answers from the passed <tt>Vector</tt>. 
	 * 
	 * @param newYesAnswers A <tt>Vector<tt> of <tt>Answer</tt> 
	 * 						objects that represent the yes answers
	 */
	public void setYesAnswers(Vector newYesAnswers) {
		
		this.yesAnswers = new Vector();
		
		Iterator i = newYesAnswers.iterator();
		
		while (i.hasNext()){
			Answer a = (Answer)i.next();
			addYesAnswer(a);
		}	
	}

	/**
	 * Tests <i>a</i> to see if it is a member of the yes answers
	 * 
	 * @param a An Answer object
	 * @return true if <i>a</i> is contained in the yes answers, false otherwise 
	 */
	public boolean isYesAnswer(Answer a)
	{
		return yesAnswers.contains(a);	
	}

	/**
	 * Tests <i>a</i> to see if it is a member of the possible answers
	 * 
	 * @param a An Answer object
	 * @return true if <i>a</i> is contained in the possible answers, false otherwise 
	 */
	public boolean isPossibleAnswer(Answer a)
	{
		return possibleAnswers.contains(a);	
	}
}
