/*
 * Created on Aug 5, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package gov.fema.web.srce.objects;

import gov.fema.web.srce.Formatter;
import gov.fema.web.srce.SRCEConstants;

import java.util.HashMap;
import java.util.Map;

/**
 * The Building class holds the data from a the buildings database table.
 * It also provides methods to access the data, and to convert the data into
 * an understandable format.
 *
 * @author n-chilson
 * 
 */
public class Building {
	
	// Provide verbose versions of field values
	// simple, except for "W", which has multiple mappings
	private static Map translations;
	
	static
	{
		translations = new HashMap();
		
		translations.put("Y_yesno", "Yes");
		translations.put("N_yesno", "No");
		
		//model building types
		translations.put("W1_model", "wood light frame");
		translations.put("W2_model", "wood (commercial or industrial)");
		translations.put("S1_model", "steel moment frame");
		translations.put("S2_model", "steel braced frame");
		translations.put("S3_model", "steel light frame");
		translations.put("S4_model", "steel frame with concrete shear walls");
		translations.put("S5_model", "steel frame with infill shear walls");
		translations.put("C1_model", "concrete moment frame");
		translations.put("C2_model", "concrete shear walls");
		translations.put("C3_model", "concrete frame with infill shear walls");
		translations.put("PC1_model", "precast concrete tilt-up walls");
		translations.put("PC2_model", "precast concrete frame with concrete shear walls");
		translations.put("RM1_model", "reinforced masonry w/ metal or wood diaphragm");
		translations.put("RM2_model", "reinforced masonry w/ precast concrete diaphragm");
		translations.put("URM_model", "unreinforced masonry");
		
		// ?? where are the occupancy classification entries?
		
		// Performance objectives
		translations.put("RR_p_obj", "risk reduction");
		translations.put("LS_p_obj", "life safety");
		translations.put("DC_p_obj", "damage control");
		translations.put("IO_p_obj", "immediate occupancy");
		
		// Rehabilitation methods		
		translations.put("SW_rehab", "added shear walls");
		translations.put("BF_rehab", "added braced frames");
		translations.put("MF_rehab", "added moment frames");
		translations.put("EW_rehab", "modified existing walls");
		translations.put("EF_rehab", "modified existing frames");
		translations.put("IS_rehab", "isolation");
		translations.put("AD_rehab", "added damping");
		translations.put("SD_rehab", "strengthened diaphragm");
		translations.put("SF_rehab", "strengthened foundations");
		translations.put("PB_rehab", "parapet bracing");
		translations.put("WT_rehab", "URM or tilt-up wall ties");
		translations.put("SS_rehab", "strengthed  soft-story only");
		
		//source of data
		translations.put("AC_source", "actual construction");
		translations.put("S_source", "study");
		
		
		// scope of non-seismic work
		translations.put("MIN_scope", "minimum work required");
		translations.put("ADD_scope", "additional improvements");
		translations.put("COM_scope", "complete renovation of interior");
		
		// socpe evaluation
		translations.put("NE_scope_eval", "not evaluated");
		translations.put("OK_scope_eval", "evaluated and OK");
		translations.put("I_scope_eval", "included in cost");
		
		// uncertainty
		translations.put("G_uncert", "good (< 5%)");
		translations.put("F_uncert", "fair (5-10%)");
		translations.put("P_uncert", "poor (> 10%)");
		
		// condition of occupants
		translations.put("IP_occup_cond", "occupants in place");
		translations.put("TR_occup_cond", "occupants temporarily removed");
		translations.put("V_occup_cond", "vacant");
		
		// roof / floor framing. Special deal for wood
		translations.put("W_framing", "wood joists / gluelams");
		translations.put("TT_framing", "truss joists / timber trusses");
		translations.put("S_framing", "steel beams");
		translations.put("C_framing", "concrete beams");
		translations.put("FS_framing", "flat slabs");
		
		// diaphragms
		translations.put("W_diaphragm", "wood (sheathing or plywood)");
		translations.put("MDF_diaphragm", "metal deck w/ concrete fill");
		translations.put("MD_diaphragm", "metal deck w/o concrete fill");
		translations.put("C_diaphragm", "cast-in-place concrete");
		translations.put("PC_diaphragm", "precast concrete");
		translations.put("ST_diaphragm", "steel truss");
		
		// cladding
		translations.put("CW_cladding", "curtain wall");
		translations.put("PC_cladding", "precast");
		translations.put("M_cladding", "masonry");
		
		// columns / bearing walls
		translations.put("W_column", "timber");
		translations.put("C_column", "concrete");
		translations.put("S_column", "steel");
		translations.put("URM_column", "unreinforced masonry");
		translations.put("RM_column", "reinforced masonry");
		
		// foundations		
		translations.put("SF_foundations", "spread footings");
		translations.put("M_foundations", "concrete mat");
		translations.put("P_foundations", "piles");
		
		// lateral systems
		translations.put("MF_laterals", "moment frames");
		translations.put("BF_laterals", "braced frames");
		translations.put("SW_laterals", "shear walls");
		
		//plan shape
		translations.put("R_plan", "rectangular");
		translations.put("L_plan", "L-shaped");
		translations.put("C_plan", "C-shaped");
		translations.put("O_plan", "O-shaped");
		translations.put("OT_plan", "other");		
		
		//condition
		translations.put("G_condition", "good");
		translations.put("F_condition", "fair");
		translations.put("P_condition", "poor");
		
		//zone - Stored in 1991 NEHRP Map Area,
		// needed to be converted to new Low-Moderate-High-Very High designation
		translations.put("1_zone", "Low");
		translations.put("2_zone", "Low");
		translations.put("3_zone", "Moderate");
		translations.put("4_zone", "Moderate");
		translations.put("5_zone", "High");
		translations.put("6_zone", "High");
		translations.put("7_zone", "Very High");				
	}

	private int id;
	private int small_tree_node;  
	private int large_tree_node;    
	private String contrib;  
	private String sub_date; // should this be a different type?
	private String county;
	private String state;
	private int zone;
	private String soil;
	private int above_stories;
	private int below_stories;
	private double area;
	private String age;
	private String model;
	private String historic;
	private String base_year;
	private double c_total;
	private String source;
	private String scope;
	private double add_space;
	private String p_obj;
	private String rehab1;
	private String rehab2;
	private String rehab3;
	private String rehab4;
	private String rehab5;
	private String rehab6;
	private String asbestos;
	private String disabled;
	private String sys_imp;
	private String repair;
	private String occup_cond;
	private String structure;
	private String ext_falling;
	private String selected_ints;
	private String all_ints;
	private double c_struct;
	private String uncert_areas;
	private String uncert_total;
	private String uncert_struct;
	private double c_relocation;
	private double c_a_e_fees;
	private double c_proj_mgr;
	private int duration;
	private double c_repair;
	private double c_asbestos;
	private double c_disabled;
	private double c_sys_imp;
	private double c_nonstruct;
	private String plan;
	private double base_x;
	private double base_y;
	private double floor_x;
	private double floor_y;
	private double story_h;
	private double total_h;
	private String roofframe;
	private String floorframe;
	private String diaphragm;
	private String cladding;
	private String settling;
	private String condition;
	private String column_type;
	private String bearing_walls;
	private String foundations;
	private String long_lateral;
	private String tran_lateral;
	private double cost_per_sf;
	private double timefactor;
	private double statefactor;
	private double totalfactor;
	private double f_c_total;
	private double f_c_struct;
	private double f_c_relocation;
	private double f_c_a_e_fees;
	private double f_c_proj_mgr;
	private double f_c_repair;
	private double f_c_asbestos;
	private double f_c_disabled;
	private double f_c_sys_imp;
	private double f_c_nonstruct;
	private double qualityfactor;
	private String code_used;
	private String special;
	private String rehab;
	
	public static String translate(String key, String fieldname)
	{
		// initialize result to original key in case the translation isn't found
		String result = key;
				
		key = key + "_" + fieldname;
		
		if (translations.containsKey(key))
		{
			result = (String)translations.get(key);
		}
		
		return result;
	}
	
	
	
	/**
	 * 
	 */
	public Building(	int id, 
						int small_tree_node,
						int large_tree_node, 
	 					String contrib,  
						String sub_date, 
						String county,
						String state,
						int zone,
						String soil,
						int above_stories,
						int below_stories,
						double area,
						String age,
						String model,
						String historic,
						String base_year,
						double c_total,
						String source,
						String scope,
						double add_space,
						String p_obj,
						String rehab1,
						String rehab2,
						String rehab3,
						String rehab4,
						String rehab5,
						String rehab6,
						String asbestos,
						String disabled,
						String sys_imp,
						String repair,
						String occup_cond,
						String structure,
						String ext_falling,
						String selected_ints,
						String all_ints,
						double c_struct,
						String uncert_areas,
						String uncert_total,
						String uncert_struct,
						double c_relocation,
						double c_a_e_fees,
						double c_proj_mgr,
						int duration,
						double c_repair,
						double c_asbestos,
						double c_disabled,
						double c_sys_imp,
						double c_nonstruct,
						String plan,
						double base_x,
						double base_y,
						double floor_x,
						double floor_y,
						double story_h,
						double total_h,
						String roofframe,
						String floorframe,
						String diaphragm,
						String cladding,
						String settling,
						String condition,
						String column_type,
						String bearing_walls,
						String foundations,
						String long_lateral,
						String tran_lateral,
						double cost_per_sf,
						double timefactor,
						double statefactor,
						double totalfactor,
						double f_c_total,
						double f_c_struct,
						double f_c_relocation,
						double f_c_a_e_fees,
						double f_c_proj_mgr,
						double f_c_repair,
						double f_c_asbestos,
						double f_c_disabled,
						double f_c_sys_imp,
						double f_c_nonstruct,
						double qualityfactor,
						String code_used,
						String special,
						String rehab) 
	{	
		this.id 		= id;  
		this.small_tree_node = small_tree_node;
		this.large_tree_node = large_tree_node;
		this.contrib 	= contrib;  
		this.sub_date 	= sub_date; // should this be a different type?
		this.county 	= county;
		this.state		= state;
		this.zone		= zone;
		this.soil		= soil;
		this.above_stories = above_stories;
		this.below_stories = below_stories;
		this.area		= area;
		this.age		= age;
		this.model		= model;
		this.historic	= historic;
		this.base_year 	= base_year;
		this.c_total	= c_total;
		this.source		= source;
		this.scope		= scope;
		this.add_space	= add_space;
		this.p_obj		= p_obj;
		this.rehab1		= rehab1;
		this.rehab2		= rehab2;
		this.rehab3		= rehab3;
		this.rehab4		= rehab4;
		this.rehab5		= rehab5;
		this.rehab6		= rehab6;
		this.asbestos	= asbestos;
		this.disabled	= disabled;
		this.sys_imp	= sys_imp;
		this.repair		= repair;
		this.occup_cond = occup_cond;
		this.structure	= structure;
		this.ext_falling = ext_falling;
		this.selected_ints = selected_ints;
		this.all_ints 	= all_ints;
		this.c_struct	= c_struct;
		this.uncert_areas = uncert_areas;
		this.uncert_total = uncert_total;
		this.uncert_struct = uncert_struct;
		this.c_relocation = c_relocation;
		this.c_a_e_fees = c_a_e_fees;
		this.c_proj_mgr = c_proj_mgr;
		this.duration = duration;
		this.c_repair = c_repair;
		this.c_asbestos = c_asbestos;
		this.c_disabled = c_disabled;
		this.c_sys_imp = c_sys_imp;
		this.c_nonstruct = c_nonstruct;
		this.plan = plan;
		this.base_x = base_x;
		this.base_y = base_y;
		this.floor_x = floor_x;
		this.floor_y = floor_y;
		this.story_h = story_h;
		this.total_h = total_h;
		this.roofframe = roofframe;
		this.floorframe = floorframe;
		this.diaphragm = diaphragm;
		this.cladding = cladding;
		this.settling = settling;
		this.condition = condition;
		this.column_type = column_type;
		this. bearing_walls = bearing_walls;
		this.foundations = foundations;
		this.long_lateral = long_lateral;
		this.tran_lateral = tran_lateral;
		this.cost_per_sf = cost_per_sf;
		this.timefactor = timefactor;
		this.statefactor = statefactor;
		this.totalfactor = totalfactor;
		this.f_c_total = f_c_total;
		this.f_c_struct = f_c_struct;
		this.f_c_relocation = f_c_relocation;
		this.f_c_a_e_fees = f_c_a_e_fees;
		this.f_c_proj_mgr = f_c_proj_mgr;
		this.f_c_repair = f_c_repair;
		this.f_c_asbestos = f_c_asbestos;
		this.f_c_disabled = f_c_disabled;
		this.f_c_sys_imp = f_c_sys_imp;
		this.f_c_nonstruct = f_c_nonstruct;
		this.qualityfactor = qualityfactor;
		this.code_used = code_used;
		this.special = special;
		this.rehab = rehab;
	}

	/**
	 * @return int
	 */
	public int getAbove_stories() {
		return above_stories;
	}

	/**
	 * @return double
	 */
	public double getAdd_space() {
		return add_space;
	}

	/**
	 * @return String
	 */
	public String getAge() {
		return age;
	}

	/**
	 * @return String
	 */
	public String getAll_ints() {
		return translate(all_ints, "scope_eval");
	}

	/**
	 * @return double
	 */
	public double getArea() {
		return area;
	}

	/**
	 * @return String
	 */
	public String getAsbestos() {
		return translate(asbestos, "yesno");
	}

	/**
	 * @return double
	 */
	public double getBase_x() {
		return base_x;
	}

	/**
	 * @return double
	 */
	public double getBase_y() {
		return base_y;
	}

	/**
	 * @return String
	 */
	public String getBase_year() {
		return base_year;
	}

	/**
	 * @return String
	 */
	public String getBearing_walls() {
		return translate(bearing_walls, "column");
	}

	/**
	 * @return int
	 */
	public int getBelow_stories() {
		return below_stories;
	}

	/**
	 * @return double
	 */
	public double getC_a_e_fees() {
		return c_a_e_fees;
	}

	/**
	 * @return double
	 */
	public double getC_asbestos() {
		return c_asbestos;
	}

	/**
	 * @return double
	 */
	public double getC_disabled() {
		return c_disabled;
	}

	/**
	 * @return double
	 */
	public double getC_nonstruct() {
		return c_nonstruct;
	}

	/**
	 * @return double
	 */
	public double getC_proj_mgr() {
		return c_proj_mgr;
	}

	/**
	 * @return double
	 */
	public double getC_relocation() {
		return c_relocation;
	}

	/**
	 * @return double
	 */
	public double getC_repair() {
		return c_repair;
	}

	/**
	 * @return double
	 */
	public double getC_struct() {
		return c_struct;
	}

	/**
	 * @return double
	 */
	public double getC_sys_imp() {
		return c_sys_imp;
	}

	/**
	 * @return double
	 */
	public double getC_total() {
		return c_total;
	}

	/**
	 * @return String
	 */
	public String getFormattedC_total()
	{
		return Formatter.formatMonetaryValue(getC_total());
	}

	/**
	 * @return double
	 */
	public double get2002C_total() {
		return c_total * SRCEConstants.FACTOR_2002;
	}
	
	/**
	 * @return String
	 */
	public String getFormatted2002C_total() {
		return Formatter.formatMonetaryValue(get2002C_total());
	}

	/**
	 * @return String
	 */
	public String getCladding() {
		return translate(cladding, "cladding");
	}

	/**
	 * @return String
	 */
	public String getCode_used() {
		return code_used;
	}

	/**
	 * @return String
	 */
	public String getColumn_type() {
		return translate(column_type, "column");
	}

	/**
	 * @return String
	 */
	public String getCondition() {
		return translate(condition, "condition");
	}

	/**
	 * @return String
	 */
	public String getContrib() {
		return contrib;
	}

	/**
	 * @return double
	 */
	public double getCost_per_sf() {
		return cost_per_sf;
	}

	/**
	 * @return String
	 */
	public String getCounty() {
		return county;
	}

	/**
	 * @return String
	 */
	public String getDiaphragm() {
		return translate(diaphragm, "diaphragm");
	}

	/**
	 * @return String
	 */
	public String getDisabled() {
		return translate(disabled, "yesno");
	}

	/**
	 * @return int
	 */
	public int getDuration() {
		return duration;
	}

	/**
	 * @return String
	 */
	public String getExt_falling() {
		return translate(ext_falling, "scope_eval");
	}

	/**
	 * @return double
	 */
	public double getF_c_a_e_fees() {
		return f_c_a_e_fees;
	}

	/**
	 * @return double
	 */
	public double getF_c_asbestos() {
		return f_c_asbestos;
	}

	/**
	 * @return double
	 */
	public double getF_c_disabled() {
		return f_c_disabled;
	}

	/**
	 * @return double
	 */
	public double getF_c_nonstruct() {
		return f_c_nonstruct;
	}

	/**
	 * @return double
	 */
	public double getF_c_proj_mgr() {
		return f_c_proj_mgr;
	}

	/**
	 * @return double
	 */
	public double getF_c_relocation() {
		return f_c_relocation;
	}

	/**
	 * @return double
	 */
	public double getF_c_repair() {
		return f_c_repair;
	}

	/**
	 * @return double
	 */
	public double getF_c_struct() {
		return f_c_struct;
	}

	/**
	 * @return double
	 */
	public double getF_c_sys_imp() {
		return f_c_sys_imp;
	}

	/**
	 * @return double
	 */
	public double getF_c_total() {
		return f_c_total;
	}

	/**
	 * @return double
	 */
	public double getFloor_x() {
		return floor_x;
	}

	/**
	 * @return double
	 */
	public double getFloor_y() {
		return floor_y;
	}

	/**
	 * @return String
	 */
	public String getFloorframe() {
		return translate(floorframe, "framing");
	}

	/**
	 * @return String
	 */
	public String getFoundations() {
		return translate(foundations, "foundations");
	}

	/**
	 * @return String
	 */
	public String getHistoric() {
		return translate(historic, "yesno");
	}

	/**
	 * @return int
	 */
	public int getId() {
		return id;
	}

	/**
	 * @return String
	 */
	public String getLong_lateral() {
		return translate(long_lateral, "laterals");
	}

	/**
	 * @return String
	 */
	public String getModel() {
		return translate(model, "model");
	}

	/**
	 * @return String
	 */
	public String getOccup_cond() {
		return translate(occup_cond, "occup_cond");
	}

	/**
	 * @return String
	 */
	public String getP_obj() {
		return translate(p_obj, "p_obj");
	}

	/**
	 * @return String
	 */
	public String getPlan() {
		return translate(plan, "plan");
	}

	/**
	 * @return double
	 */
	public double getQualityfactor() {
		return qualityfactor;
	}

	/**
	 * @return String
	 */
	public String getRehab() {
		String parsedRehab = rehab;
		
		parsedRehab = parsedRehab.replace('.', ' ');
			
		return parsedRehab;
	}

	/**
	 * @return String
	 */
	public String getRehab1() {
		return translate(rehab1, "rehab");
	}

	/**
	 * @return String
	 */
	public String getRehab2() {
		return translate(rehab2, "rehab");
	}

	/**
	 * @return String
	 */
	public String getRehab3() {
		return translate(rehab3, "rehab");
	}

	/**
	 * @return String
	 */
	public String getRehab4() {
		return translate(rehab4, "rehab");
	}

	/**
	 * @return String
	 */
	public String getRehab5() {
		return translate(rehab5, "rehab");
	}

	/**
	 * @return String
	 */
	public String getRehab6() {
		return translate(rehab6, "rehab");
	}

	/**
	 * @return String
	 */
	public String getRepair() {
		return translate(repair, "yesno");
	}

	/**
	 * @return String
	 */
	public String getRoofframe() {
		return translate(roofframe, "framing");
	}

	/**
	 * @return String
	 */
	public String getScope() {
		return translate(scope, "scope");
	}

	/**
	 * @return String
	 */
	public String getSelected_ints() {
		return translate(selected_ints, "scope_eval");
	}

	/**
	 * @return String
	 */
	public String getSettling() {
		return translate(settling, "yesno");
	}

	/**
	 * @return String
	 */
	public String getSoil() {
		return soil;
	}

	/**
	 * @return String
	 */
	public String getSource() {
		return translate(source, "source");
	}

	/**
	 * @return String
	 */
	public String getSpecial() {
		return special;
	}

	/**
	 * @return String
	 */
	public String getState() {
		return state;
	}

	/**
	 * @return double
	 */
	public double getStatefactor() {
		return statefactor;
	}

	/**
	 * @return double
	 */
	public double getStory_h() {
		return story_h;
	}

	/**
	 * @return String
	 */
	public String getStructure() {
		return translate(structure, "scope_eval");
	}

	/**
	 * @return String
	 */
	public String getSub_date() {
		return sub_date;
	}

	/**
	 * @return String
	 */
	public String getSys_imp() {
		return translate(sys_imp, "yesno");
	}

	/**
	 * @return double
	 */
	public double getTimefactor() {
		return timefactor;
	}

	/**
	 * @return double
	 */
	public double getTotal_h() {
		return total_h;
	}

	/**
	 * @return double
	 */
	public double getTotalfactor() {
		return totalfactor;
	}

	/**
	 * @return String
	 */
	public String getTran_lateral() {
		return translate(tran_lateral, "laterals");
	}

	/**
	 * @return String
	 */
	public String getUncert_areas() {
		return translate(uncert_areas, "uncert");
	}

	/**
	 * @return String
	 */
	public String getUncert_struct() {
		return translate(uncert_struct, "uncert");
	}

	/**
	 * @return String
	 */
	public String getUncert_total() {
		return translate(uncert_total, "uncert");
	}

	/**
	 * @return String
	 */
	public String getZone() {
		return translate(Integer.toString(zone), "zone");
	}

	/**
	 * @param i
	 */
	public void setAbove_stories(int i) {
		above_stories = i;
	}

	/**
	 * @param d
	 */
	public void setAdd_space(double d) {
		add_space = d;
	}

	/**
	 * @param string
	 */
	public void setAge(String string) {
		age = string;
	}

	/**
	 * @param string
	 */
	public void setAll_ints(String string) {
		all_ints = string;
	}

	/**
	 * @param d
	 */
	public void setArea(double d) {
		area = d;
	}

	/**
	 * @param string
	 */
	public void setAsbestos(String string) {
		asbestos = string;
	}

	/**
	 * @param d
	 */
	public void setBase_x(double d) {
		base_x = d;
	}

	/**
	 * @param d
	 */
	public void setBase_y(double d) {
		base_y = d;
	}

	/**
	 * @param string
	 */
	public void setBase_year(String string) {
		base_year = string;
	}

	/**
	 * @param string
	 */
	public void setBearing_walls(String string) {
		bearing_walls = string;
	}

	/**
	 * @param i
	 */
	public void setBelow_stories(int i) {
		below_stories = i;
	}

	/**
	 * @param d
	 */
	public void setC_a_e_fees(double d) {
		c_a_e_fees = d;
	}

	/**
	 * @param d
	 */
	public void setC_asbestos(double d) {
		c_asbestos = d;
	}

	/**
	 * @param d
	 */
	public void setC_disabled(double d) {
		c_disabled = d;
	}

	/**
	 * @param d
	 */
	public void setC_nonstruct(double d) {
		c_nonstruct = d;
	}

	/**
	 * @param d
	 */
	public void setC_proj_mgr(double d) {
		c_proj_mgr = d;
	}

	/**
	 * @param d
	 */
	public void setC_relocation(double d) {
		c_relocation = d;
	}

	/**
	 * @param d
	 */
	public void setC_repair(double d) {
		c_repair = d;
	}

	/**
	 * @param d
	 */
	public void setC_struct(double d) {
		c_struct = d;
	}

	/**
	 * @param d
	 */
	public void setC_sys_imp(double d) {
		c_sys_imp = d;
	}

	/**
	 * @param d
	 */
	public void setC_total(double d) {
		c_total = d;
	}

	/**
	 * @param string
	 */
	public void setCladding(String string) {
		cladding = string;
	}

	/**
	 * @param string
	 */
	public void setCode_used(String string) {
		code_used = string;
	}

	/**
	 * @param string
	 */
	public void setColumn_type(String string) {
		column_type = string;
	}

	/**
	 * @param string
	 */
	public void setCondition(String string) {
		condition = string;
	}

	/**
	 * @param string
	 */
	public void setContrib(String string) {
		contrib = string;
	}

	/**
	 * @param d
	 */
	public void setCost_per_sf(double d) {
		cost_per_sf = d;
	}

	/**
	 * @param string
	 */
	public void setCounty(String string) {
		county = string;
	}

	/**
	 * @param string
	 */
	public void setDiaphragm(String string) {
		diaphragm = string;
	}

	/**
	 * @param string
	 */
	public void setDisabled(String string) {
		disabled = string;
	}

	/**
	 * @param i
	 */
	public void setDuration(int i) {
		duration = i;
	}

	/**
	 * @param string
	 */
	public void setExt_falling(String string) {
		ext_falling = string;
	}

	/**
	 * @param d
	 */
	public void setF_c_a_e_fees(double d) {
		f_c_a_e_fees = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_asbestos(double d) {
		f_c_asbestos = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_disabled(double d) {
		f_c_disabled = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_nonstruct(double d) {
		f_c_nonstruct = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_proj_mgr(double d) {
		f_c_proj_mgr = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_relocation(double d) {
		f_c_relocation = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_repair(double d) {
		f_c_repair = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_struct(double d) {
		f_c_struct = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_sys_imp(double d) {
		f_c_sys_imp = d;
	}

	/**
	 * @param d
	 */
	public void setF_c_total(double d) {
		f_c_total = d;
	}

	/**
	 * @param d
	 */
	public void setFloor_x(double d) {
		floor_x = d;
	}

	/**
	 * @param d
	 */
	public void setFloor_y(double d) {
		floor_y = d;
	}

	/**
	 * @param string
	 */
	public void setFloorframe(String string) {
		floorframe = string;
	}

	/**
	 * @param string
	 */
	public void setFoundations(String string) {
		foundations = string;
	}

	/**
	 * @param string
	 */
	public void setHistoric(String string) {
		historic = string;
	}

	/**
	 * @param i
	 */
	public void setId(int i) {
		id = i;
	}

	/**
	 * @param string
	 */
	public void setLong_lateral(String string) {
		long_lateral = string;
	}

	/**
	 * @param string
	 */
	public void setModel(String string) {
		model = string;
	}

	/**
	 * @param string
	 */
	public void setOccup_cond(String string) {
		occup_cond = string;
	}

	/**
	 * @param string
	 */
	public void setP_obj(String string) {
		p_obj = string;
	}

	/**
	 * @param string
	 */
	public void setPlan(String string) {
		plan = string;
	}

	/**
	 * @param d
	 */
	public void setQualityfactor(double d) {
		qualityfactor = d;
	}

	/**
	 * @param string
	 */
	public void setRehab(String string) {
		rehab = string;
	}

	/**
	 * @param string
	 */
	public void setRehab1(String string) {
		rehab1 = string;
	}

	/**
	 * @param string
	 */
	public void setRehab2(String string) {
		rehab2 = string;
	}

	/**
	 * @param string
	 */
	public void setRehab3(String string) {
		rehab3 = string;
	}

	/**
	 * @param string
	 */
	public void setRehab4(String string) {
		rehab4 = string;
	}

	/**
	 * @param string
	 */
	public void setRehab5(String string) {
		rehab5 = string;
	}

	/**
	 * @param string
	 */
	public void setRehab6(String string) {
		rehab6 = string;
	}

	/**
	 * @param string
	 */
	public void setRepair(String string) {
		repair = string;
	}

	/**
	 * @param string
	 */
	public void setRoofframe(String string) {
		roofframe = string;
	}

	/**
	 * @param string
	 */
	public void setScope(String string) {
		scope = string;
	}

	/**
	 * @param string
	 */
	public void setSelected_ints(String string) {
		selected_ints = string;
	}

	/**
	 * @param string
	 */
	public void setSettling(String string) {
		settling = string;
	}

	/**
	 * @param string
	 */
	public void setSoil(String string) {
		soil = string;
	}

	/**
	 * @param string
	 */
	public void setSource(String string) {
		source = string;
	}

	/**
	 * @param string
	 */
	public void setSpecial(String string) {
		special = string;
	}

	/**
	 * @param string
	 */
	public void setState(String string) {
		state = string;
	}

	/**
	 * @param d
	 */
	public void setStatefactor(double d) {
		statefactor = d;
	}

	/**
	 * @param d
	 */
	public void setStory_h(double d) {
		story_h = d;
	}

	/**
	 * @param string
	 */
	public void setStructure(String string) {
		structure = string;
	}

	/**
	 * @param string
	 */
	public void setSub_date(String string) {
		sub_date = string;
	}

	/**
	 * @param string
	 */
	public void setSys_imp(String string) {
		sys_imp = string;
	}

	/**
	 * @param d
	 */
	public void setTimefactor(double d) {
		timefactor = d;
	}

	/**
	 * @param d
	 */
	public void setTotal_h(double d) {
		total_h = d;
	}

	/**
	 * @param d
	 */
	public void setTotalfactor(double d) {
		totalfactor = d;
	}

	/**
	 * @param string
	 */
	public void setTran_lateral(String string) {
		tran_lateral = string;
	}

	/**
	 * @param string
	 */
	public void setUncert_areas(String string) {
		uncert_areas = string;
	}

	/**
	 * @param string
	 */
	public void setUncert_struct(String string) {
		uncert_struct = string;
	}

	/**
	 * @param string
	 */
	public void setUncert_total(String string) {
		uncert_total = string;
	}

	/**
	 * @param i
	 */
	public void setZone(int i) {
		zone = i;
	}

	/**
	 * @return int
	 */
	public int getLarge_tree_node() {
		return large_tree_node;
	}

	/**
	 * @return int
	 */
	public int getSmall_tree_node() {
		return small_tree_node;
	}

	/**
	 * @param i
	 */
	public void setLarge_tree_node(int i) {
		large_tree_node = i;
	}

	/**
	 * @param i
	 */
	public void setSmall_tree_node(int i) {
		small_tree_node = i;
	}

	

}
