/*
 * Created on Aug 1, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package gov.fema.web.srce.objects;


import java.util.Map;
import java.util.Vector;

import org.apache.log4j.Logger;

import gov.fema.web.srce.ConstantsManager;


/**
 * @author n-chilson
 *
 * This tree enables the submission of a whole set of answers
 * to be matched with questions in hopes of calculating the final 
 * result node. The reason this class is seperate from the standard decision
 * tree is that there are a different set of answers for each question
 * in an Expert Tree. Regular trees have yes/no answers. The Expert tree has 
 * to handle multiple choice answers.
 * 
 */
public class ExpertDecisionTree extends DecisionTree {

	protected static final Logger logger = org.apache.log4j.Logger.getLogger(ExpertDecisionTree.class);
	
	public ExpertDecisionTree() {
		super();
	}
	
	public ExpertDecisionTree(String method, TreeNode root, Map nodes)
	{
		super(method, root, nodes);
		this.mode = EXPERT_MODE;
	}
	
	/**
	 *  Walks the decision tree as far as possible with the given set of answers.
	 *  Returns the last reachable node.
	 * 
	 *  @param  givenAnswers	a map of Question/Answer pairs.
	 *  @return the final node reached (may or may not be a terminal node) 
	 */
	public TreeNode answerQuestions(Map givenAnswers)
	{
		TreeNode currNode = root;

		//	retrieve the answer matching this question from the Map
		Question nodeQ = ((DecisionNode)currNode).getQuestion();
		Answer givenAnswer = (Answer)givenAnswers.get(nodeQ);
			
		while( 	currNode.isDecisionNode() && 
				!(givenAnswer.equals(Answer.Unknown())))
		{
			currNode = ((DecisionNode)currNode).answerQuestion(givenAnswer);
			if (currNode != null)
			{
				if (!currNode.isTerminalNode())
				{
					nodeQ = ((DecisionNode)currNode).getQuestion();
					givenAnswer = (Answer)givenAnswers.get(nodeQ);	
				}
			}
		}
		return currNode;		
	}
	
	public Vector getQuestions()
	{
		Vector questions = new Vector();

		if( method.equals(METHOD_1))
		{ 		
			questions.add(Question.createBuildYearQ());
			questions.add(Question.createPrimaryObjectiveQ());
			questions.add(Question.createSeismicQ());
			questions.add(Question.createBuildingModelQ());
			questions.add(Question.createAreaQ());
		}
		else
		{
			questions.add(Question.createBuildYearQ());
			questions.add(Question.createScopeAddQ());
			questions.add(Question.createPrimaryObjectiveQ());
			questions.add(Question.createAreaQ());
			questions.add(Question.createSoilTypeQ());
			questions.add(Question.createOccupancyQ());
			questions.add(Question.createSeismicQ());
			questions.add(Question.createBelowStreetQ());
			questions.add(Question.createAboveStreetQ());
			questions.add(Question.createBuildingModelQ());
			questions.add(Question.createOccupancyClassQ());
			questions.add(Question.createSysImpQ());
			questions.add(Question.createDiaphragmQ());
			questions.add(Question.createStoryHeightQ());
			questions.add(Question.createFloorPlanQ());
			questions.add(Question.createRehabMethodQ());
			questions.add(Question.createHistoricQ());
			questions.add(Question.createFoundationQ());
			questions.add(Question.createCladdingQ());
			questions.add(Question.createBearingWallQ());
			questions.add(Question.createColumnQ());
		}		
		
		return questions;	
	}
	
	/**
	 * @return - A Map of all the answers used in this tree.
	 * 
	 */  
	public Map getAnswers()
	{
		ConstantsManager cm = new ConstantsManager();
		
		Map answers = cm.getAnswers(method);
    	
    	logger.debug("There are answers for " + answers.size() + " questions being returned.");
    	logger.debug("Setup: " + answers.toString());
    	
    	cm = null;
    	
    	return answers;
	}
}
