/*
 * Created on Jun 4, 2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package gov.fema.web.srce.objects;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.TreeMap;

/**
 * @author Neil
 *
 * This class stores the previous answers in a TreeMap, sorted by nodeID. This ensures that the answers 
 * are in the order they were given. The map is keyed by nodeId, allowing retrevial in order given.
 * 
 * "re" inserting an answer to a question invalidates all the answers below in the sort order.
 * 
 * For the web pages, there is the "collapse" function that gives only a list of each DIFFERENT question
 *  asked, with the latest answer and the node at which that answer was given.
 */
public class PreviousAnswers {
	TreeMap prevAnswers;
	
	/**
	 * Default constructor
	 */
	public PreviousAnswers() {
		super();
		this.prevAnswers = new TreeMap();
	}
	
	public void add(TreeNode node, Answer ans)
	{
		//If this node has already been visited, remove it and all subsequent nodes. 
		if (prevAnswers.containsKey(node))
		{
			clearToEndFrom(node);		
		}
		
		prevAnswers.put(node, ans);
	}
	
	/**
	 * Clears nodes from list, starting with startNode and goign to the end.
	 * 
	 * @param startNode - the key into the map from which to start clearing the
	 *  map.
	 *  
	 */
	public void clearToEndFrom(TreeNode startNode) {
		Map invalidAnswers = prevAnswers.tailMap(startNode);
		invalidAnswers.clear(); // this carries through to the prevAnswers array,  
								// so should remove the duplicate and all following it.
	}

	/**
	 * @return Returns the prevAnswers, a map of answers indexed by node.
	 */
	public TreeMap getPrevAnswers() {
		return prevAnswers;
	}
	
	/**
	 * @return a treemap of nodes to answers. The nodes all have unique questions and are maintained in order by id.
	 */
	public TreeMap getUniqueQuestionAnswerPairs()
	{
		TreeMap result = new TreeMap();
		Map questionIndex = new HashMap();
		
		Set nodes = prevAnswers.keySet();
		Iterator i = nodes.iterator();
		
		// build an index of nodes keyed by question;
		while (i.hasNext() )
		{
			DecisionNode node = (DecisionNode) i.next();
			
			// insert into keyed by question index if it isn't there or if
			// the answer in there has been replaced.
			if ( ! questionIndex.containsKey(node.getQuestion()))
			{
				questionIndex.put(node.getQuestion(), node);
			}
			else 
			{
				//see if this node is later in the chain than the previous same question
				DecisionNode oldNode = (DecisionNode) questionIndex.get(node.getQuestion());
				if (oldNode.getId() <= node.getId())
				{
					// replace it because this answer came later.
					questionIndex.put(node.getQuestion(), node);
				}

			}
		}
		
		// at this point, the questionIndex has the latest nodes for which any question was asked
		// Now we can build the node-> answer index.
		i = questionIndex.values().iterator();
		while (i.hasNext())
		{
			DecisionNode node = (DecisionNode) i.next();
			Answer ans = (Answer) prevAnswers.get(node);
			
			result.put(node, ans);
		}
		
		return result;	
	}
}
