/*
 * Created on Jul 10, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package gov.fema.web.srce.objects;

import org.apache.log4j.Logger;

import gov.fema.web.srce.SRCEConstants;

/**
 * @author n-chilson
 *
 * A class that is its own factory for questions. 
 * There are a limited and set number of questions, so 
 * I've provided a method to create each of them.
 * 
 * 1-21-04 - modified to read from SRCEConstants
 */
public class Question {

	public static final String BUILD_YEAR_NAME			= "yearConstructed";
	public static final String PRIMARY_OBJECTIVE_NAME	= "performanceObjective";
	public static final String SEISMIC_NAME				= "seismicZone";
	public static final String BUILDING_MODEL_NAME		= "buildingModel";
	public static final String AREA_NAME				= "area";

	public static final String SCOPE_ADD_NAME		= "scopeAdd";
	public static final String SOIL_TYPE_NAME		= "soilType";
	public static final String OCCUPANCY_NAME		= "occupancy";
	public static final String BELOW_STREET_NAME	= "belowStreet";
	public static final String ABOVE_STREET_NAME	= "aboveStreet";
	public static final String OCCUPANCY_CLASS_NAME	= "occupancyClass";
	public static final String SYS_IMP_NAME			= "sysImp";
	public static final String DIAPHRAGM_NAME		= "diaphragm";
	public static final String STORY_HEIGHT_NAME	= "storyHeight";
	public static final String FLOOR_PLAN_NAME		= "floorPlan";
	public static final String REHAB_METHOD_NAME	= "rehabMethod";
	public static final String HISTORIC_NAME		= "historic";
	public static final String FOUNDATION_NAME		= "foundation";
	public static final String CLADDING_NAME		= "cladding";
	public static final String BEARING_WALL_NAME	= "bearingWall";
	public static final String COLUMN_NAME			= "column"; 
	
	protected static final Logger logger = org.apache.log4j.Logger.getLogger(Question.class);
	
    // Object Properties
	private String name;
	private String text;
	private String helpFilename;
		
	public Question()
	{
		text = "None";
	}
	
	public Question(String name, String questionText, String helpFilename)	
	{
		this.name = name;
		this.text = questionText;
		this.helpFilename = helpFilename;			
	}
	
	public static Question createQuestion(String name)
	{
		Question question = (Question) SRCEConstants.getQuestions().get(name);
		if (question != null)
		{
			logger.debug( "Got question: " + name );
			logger.debug( "  =  " + question.getText());
		}
		else
		{
			logger.debug( "Failed to get a question for name " + name);
		}
		return question;
	}
	
	// factory methods

	public static Question createBuildYearQ()
	{
		return createQuestion(BUILD_YEAR_NAME);
	}

	public static Question createPrimaryObjectiveQ()
	{
		return createQuestion(PRIMARY_OBJECTIVE_NAME);
	}
	
	public static Question createSeismicQ()
	{
		return createQuestion(SEISMIC_NAME);
	}
		
	public static Question createBuildingModelQ()
	{
		return createQuestion(BUILDING_MODEL_NAME);
	}
	
	public static Question createAreaQ()
	{
		return createQuestion(AREA_NAME);
	}
	
	/** Questions for large tree only **/

	public static Question createScopeAddQ() 
	{
		return createQuestion(SCOPE_ADD_NAME);
	}

	public static Question createSoilTypeQ() 
	{
		return createQuestion(SOIL_TYPE_NAME);
	}

	public static Question createOccupancyQ() 
	{
		return createQuestion(OCCUPANCY_NAME);
	}

	public static Question createBelowStreetQ() 
	{
		return createQuestion(BELOW_STREET_NAME);
	}
	
	public static Question createAboveStreetQ() 
	{
		return createQuestion(ABOVE_STREET_NAME);
	}
	
	public static Question createOccupancyClassQ() 
	{
		return createQuestion(OCCUPANCY_CLASS_NAME);
	}
	
	public static Question createSysImpQ() 
	{
		return createQuestion(SYS_IMP_NAME);
	}
	
	public static Question createDiaphragmQ() 
	{
		return createQuestion(DIAPHRAGM_NAME);
	}
	
	public static Question createStoryHeightQ() 
	{
		return createQuestion(STORY_HEIGHT_NAME);
	}
	
	public static Question createFloorPlanQ() 
	{
		return createQuestion(FLOOR_PLAN_NAME);
	}
	
	public static Question createRehabMethodQ() 
	{
		return createQuestion(REHAB_METHOD_NAME);
	}
	
	public static Question createHistoricQ() 
	{
		return createQuestion(HISTORIC_NAME);
	}
	
	public static Question createFoundationQ() 
	{
		return createQuestion(FOUNDATION_NAME);
	}
	
	public static Question createCladdingQ() 
	{
		return createQuestion(CLADDING_NAME);
	}
	
	public static Question createBearingWallQ() 
	{
		return createQuestion(BEARING_WALL_NAME);
	}
	
	public static Question createColumnQ() 
	{
		return createQuestion(COLUMN_NAME);
	}


	/**
	 * @return String
	 */
	public String getName() {
		return name;
	}

	/**
	 * @return String
	 */
	public String getText() {
		return text;
	}
	
	/**
	 * @return String
	 */
	public String getHelpFilename() {
		return helpFilename;
	}
		
	/**
	 * @return boolean
	 */
	public boolean equals(Object obj)
	{
		boolean result = false;
		
		// can shortcut out of this if objects are same
		if (this == obj)
			return true;
			
		if (obj != null && getClass() == obj.getClass())
		{
			logger.debug( "in Q.equals() - Object not null and of same class"); 
			Question question = (Question)obj;
			logger.debug( this.getText() + " ?=? " + question.getText() );
			
			if (this.getText().equals(question.getText()))
			{
				result = true;
			}
		}	
		
		return result;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return text;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return text.hashCode();
	}
}
