/**
 * Title:        OGE Travel
 * Description:
 * Copyright:    Copyright (c) 2003
 * Company:      Federal Emergency Management Agency
 * 
 * @version 1.0
 * 
 * $Id: AbstractActionBase.java 9735 2007-07-12 16:10:30Z asharkova $
 * 
 * AbstractActionBase is a base class for all Struts actions defined for
 * the project.  It contains components that are common to all
 * actions used in the project, such as a listing of commonly used
 * global forwards.
 * 
 */


package gov.fema.web.srce.struts.actions;

import java.util.Vector;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import gov.fema.web.srce.objects.DecisionTree;
import gov.fema.web.srce.objects.PreviousAnswers;
import gov.fema.web.srce.objects.TreeNode;

public class AbstractActionBase extends Action {

    /* Generic typical returns used so that the structs-config.xml can use
     * default global forwards.
     */
    protected static final String SUCCESS 			= "success";
    protected static final String FAILURE 			= "failure";
    protected static final String ERROR 			= "error";
    protected static final String BACK 				= "back";
    
	protected static final String INITIALIZE_METHOD = "InitializeMethod";  
    protected static final String INITIALIZE_MODE   = "InitializeMode";
	protected static final String ANSWER 			= "Answer";
	protected static final String TERMINAL 			= "Terminal";
	protected static final String EXPERT 			= "Expert";
	protected static final String VIEW_BUILDINGS		= "ViewBuildings";
	protected static final String VIEW_BUILDING_DETAILS		= "ViewBuildingDetails";
	protected static final String LOCATION			= "Location";
	
	protected static final Logger logger = org.apache.log4j.Logger.getLogger(AbstractActionBase.class);
	
    public AbstractActionBase() {
    }
		
	/**
	 * Method getDecisionTree
	 * 
	 * Pulls the current decision tree(if there is one) from the session variable.
	 * Returns null if no tree exists.
	 * 
	 * @param request
	 * @return DecisionTree - The current decision tree. 
	 */
	protected DecisionTree getDecisionTree(HttpServletRequest request) {
		// See if we have an existing decisionTree object
		
		DecisionTree dt = (DecisionTree)(request.getSession(true).getAttribute("decisionTree"));
	
		return dt;
	}
		
	/**
	 * Method getPreviousAnswers
	 * 
	 * Pulls the previousAnswers object from the session variable if it exists.
	 * If null, creates a new one and adds it to the session variable.
	 * (lazy initialization) 
	 * 
	 * @param request
	 * @return PreviousAnswers - a map of questions to given answers.
	 */
	protected PreviousAnswers getPreviousAnswers( HttpServletRequest request ) {
		// See if we have an existing Map object
		PreviousAnswers prevAnswers = (PreviousAnswers)request.getSession().getAttribute("prevAnswers");
		// If we don't have an existing object - create a new one, add to session
		if (prevAnswers == null) 
		{
			prevAnswers = new PreviousAnswers();
			request.getSession().setAttribute("prevAnswers", prevAnswers);
		}
		
		return prevAnswers;
	}

   
	/**
	 * Method setCurrentNode
	 * 
	 * Adds the passed node to the request's attribute list.
	 * Used by JSPs.
	 * 
	 * @param currentNode	- node to be added
	 * @param request
	 */
	protected void setCurrentNode(TreeNode currentNode,  HttpServletRequest request) 
	{
		if (currentNode != null)
		{
			request.setAttribute("currentNode", currentNode);
		}
		else
		{
			logger.error("ERROR - Current node set to null node.");		
		}
	}
	
	/**
	 * Method setPreviousNodes
	 * 
	 * Adds the Vector of nodes to the request's attribute list.
	 * Used by JSPs.
	 * 
	 * @param prevNodes	- nodes to be added
	 * @param request
	 */
	protected void setPreviousNodes(Vector prevNodes, HttpServletRequest request) {
		request.setAttribute("prevNodes", prevNodes);
	}
			
	/**
	 * Method ValidateSessionAttributes
	 * 
	 * Verifies that the decision tree and location attributes are
	 * present in the session. Adds errors to the ActionMessages collection if not.
	 * 
	 * @param request
	 * @param errors
	 */
	protected void ValidateSessionAttributes(HttpServletRequest request, 
											 ActionMessages errors)
	{
		DecisionTree dt = (DecisionTree)(request.getSession(true).getAttribute("decisionTree"));
		if (dt == null)
		{
			errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("error.generic", "Your session has timed out. Please restart your estimate. (Decision tree does not exist)"));
		}
		
		String location = (String)(request.getSession(true).getAttribute("location"));
		if (location == null)
		{
			errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("error.generic", "Your session has timed out. Please restart your estimate. (Location not set)"));
		}	
											 
	}
}

