package gov.fema.web.srce.struts.actions;

import java.util.Vector;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import gov.fema.web.srce.objects.Answer;
import gov.fema.web.srce.objects.DecisionNode;
import gov.fema.web.srce.objects.DecisionTree;
import gov.fema.web.srce.objects.PreviousAnswers;
import gov.fema.web.srce.objects.TreeNode;
import gov.fema.web.srce.struts.forms.AnswerForm;

public class AnswerAction extends AbstractActionBase {
		
	protected static final Logger logger = org.apache.log4j.Logger.getLogger(AnswerAction.class);
	
	/**
	 * @see org.apache.struts.action.Action#execute(org.apache.struts.action.ActionMapping, org.apache.struts.action.ActionForm, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	public ActionForward execute( 	ActionMapping mapping,
									ActionForm form,
									HttpServletRequest request,
									HttpServletResponse response)
									throws Exception {
		
		AnswerForm answerForm = (AnswerForm)form;
		ActionForward actionForward = null;
		ActionMessages errors = new ActionMessages();
	
		ValidateSessionAttributes(request, errors);
		if(!errors.isEmpty())
		{
			saveErrors(request, errors);
			return mapping.findForward(ERROR);
		}

		if (answerForm.isBegin()) {
			actionForward = doBegin(mapping, answerForm, request, response,	errors);	
		}
		else if (answerForm.isAnswer()) {
			actionForward = doAnswer(mapping, answerForm, request, response, errors);
		}
		else if (answerForm.isBackup())
		{
			actionForward = doBackup(mapping, answerForm, request, response, errors);
		}
		else
		{
			// unknown action
			logger.error("ERROR - Unknown Action");
			errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("error.generic", "Unknown action" + answerForm.getAction()));
		}
		
		if(!errors.isEmpty())
		{
			saveErrors(request, errors);
			actionForward = mapping.findForward(ERROR);
		}
		
		return (actionForward);
	}
  
    
/*
 *  The following methods perform each of the "subactions" for this action class. 
 * 
 * The JSP gets 4 bean data objects to work with: 
 *    currentNode (request scope) - the relevant data about the latest node in the tree
 *    prevQuestions (request scope) - a Vector of the Question properties for all the current nodes' parents
 * 	  prevAnswers (session scope) - a Map of all the given answers, with the nodeID of the node they were given for as the key.  	
 *    prevNodes (request scope) - a Vector of all the ancestor nodes of the current node.
 */
 
	/**
	 * First entry into this action; sets up neccesary objects.
	 * 
	 * @param mapping
	 * @param answerForm
	 * @param request
	 * @param response
	 * @param errors
	 * @return ActionForward - tells struts where to go to next.
	 * @throws Exception
	 */ 
    private ActionForward doBegin(	ActionMapping mapping,
									AnswerForm answerForm,
									HttpServletRequest request,
									HttpServletResponse response,
									ActionMessages errors)
									throws Exception
    {

		DecisionTree decisionTree = getDecisionTree(request);
		if (decisionTree == null)
		{
			// TODO: need to forward to a page that says they've logged out.
			return mapping.findForward(ERROR);
		}

		//we need to start at the root of the tree		 
		setCurrentNode(decisionTree.getRoot(), request);
		logger.debug("Root: " + decisionTree.getRoot().getId());
		logger.debug("Root.question: " + ((DecisionNode)decisionTree.getRoot()).getQuestion().getText()); 
		
		// do this just to make sure this object exists
		getPreviousAnswers(request); // uses lazy initialization
		setPreviousNodes(new Vector(), request);

		return mapping.findForward(ANSWER);
    }
    
    
    /**
     * Given an answer, tries to find the next proper node to go to. 
     * 
	 * @param mapping
	 * @param answerForm
	 * @param request
	 * @param response
	 * @param errors
	 * @return ActionForward - Tells struts where to go to next.
	 * @throws Exception
	 */
	private ActionForward doAnswer(	ActionMapping mapping,
									AnswerForm answerForm,
									HttpServletRequest request,
									HttpServletResponse response,
									ActionMessages errors)
									throws Exception
    {
    	DecisionTree decisionTree = getDecisionTree(request);
    	
    	if (decisionTree == null)
    	{
    		// TODO: need to forward to a page that says they've logged out.
			return mapping.findForward(ERROR);
    	}
    	
		TreeNode newNode = null;
    	
    	//scrape form
		Answer answer = new Answer(answerForm.getAnswerText());
		int nodeId = Integer.parseInt(answerForm.getNodeID());
	
		//find & set next node
		newNode = decisionTree.answerQuestion(nodeId, answer);
		setCurrentNode(newNode, request);
		
		//update history objects
		updatePreviousAnswers(nodeId, answer, request);
		setPreviousNodes(decisionTree.collectParentNodes(newNode.getId()), request);

		// figure out which view is appropriate
		if (newNode.isTerminalNode())
		{
			return mapping.findForward(TERMINAL);
		}
		else
		{
			return mapping.findForward(ANSWER);
		}
    }
    
	/**
	 * Add the just answered question to the previous answers map.
	 * 
	 * @param nodeId  -  new node
	 * @param answer  -  given answer
	 * @param request -  the request object.
	 */
	private void updatePreviousAnswers(int nodeId, Answer answer, HttpServletRequest request) 
	{
		TreeNode treeNode = getDecisionTree(request).getNode(nodeId);
		
		if (treeNode.isDecisionNode())
		{
			DecisionNode dn = (DecisionNode) treeNode;
			PreviousAnswers prevAnswers = getPreviousAnswers(request);
			
			prevAnswers.add(dn, answer);
		}
		else
		{
			//this shouldn't happen
			logger.error("Error in updatePreviousAnswers - tried to added a terminal node");
		}
	}

	/**
	 * Moves up the decision tree.
	 * 
	 * This action is invoked whenever a user moves back up the decision tree
	 * by clicking on an answer the previous answers list.
	 * 
	 * @param mapping
	 * @param answerForm
	 * @param request
	 * @param response
	 * @param errors
	 * @return ActionForward - tells struts where to go next
	 * @throws Exception
	 */
	private ActionForward doBackup(	ActionMapping mapping,
									AnswerForm answerForm,
									HttpServletRequest request,
									HttpServletResponse response,
									ActionMessages errors)
									throws Exception
	{	
		DecisionTree decisionTree = getDecisionTree(request);
		if (decisionTree == null)
		{
			// TODO: need to forward to a page that says they've logged out.
			return mapping.findForward(ERROR);
		}
	
		// scrape form
		int nodeId = Integer.parseInt(answerForm.getNodeID());
				
		// find & set next node
		TreeNode newNode = decisionTree.getNode(nodeId);	
		setCurrentNode(newNode, request);

		// update history objects 
		
		// need to clear any outdated answered nodes further down the tree than the "backed up to" node. 
		PreviousAnswers pa = getPreviousAnswers(request);
		pa.clearToEndFrom(newNode.getParent());
				
		setPreviousNodes(decisionTree.collectParentNodes(newNode.getId()), request);

		// figure out which view is appropriate
		if (newNode.isTerminalNode())
		{
			// shouldn't actually be able to "back up" to a terminal node,
			// but included for the crafty URL hacker.
			return mapping.findForward(TERMINAL);
		}
		else
		{
			return mapping.findForward(ANSWER);
		}
	}
}
