/*
 * Created on Aug 7, 2003
 *
 */
package gov.fema.web.srce.struts.actions;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import gov.fema.web.srce.BuildingManager;
import gov.fema.web.srce.objects.DecisionTree;
import gov.fema.web.srce.struts.forms.ViewForm;

/**
 * @author n-chilson
 *
 *  */
public class ViewAction extends AbstractActionBase {

	/**
	 * Default Constructor
	 */
	public ViewAction() {
		super();
	}

	/**
	 * @see org.apache.struts.action.Action#execute(org.apache.struts.action.ActionMapping, org.apache.struts.action.ActionForm, javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	public ActionForward execute( 	ActionMapping mapping,
									ActionForm form,
									HttpServletRequest request,
									HttpServletResponse response)
									throws Exception {

		ViewForm viewForm = (ViewForm)form;
		ActionForward actionForward = null;
		ActionMessages errors = new ActionMessages();
	
		if (viewForm.isViewBuildings()) 
		{
			actionForward = doViewBuildings(mapping, viewForm, request, response, errors);	
		}
		else if (viewForm.isViewBuildingDetails())
		{
			actionForward = doViewBuildingDetail(mapping, viewForm, request, response, errors);
		}
		else
		{
			// unknown action
			logger.error("ERROR - Unknown action");
			errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("error.generic", "Unknown action" + viewForm.getAction()));
		}
	
		if(!errors.isEmpty())
		{
			saveErrors(request, errors);
			actionForward = mapping.findForward(ERROR);
		}
	
		return (actionForward);
	}

	/**
	 * Retrieves all the buildings associated with
	 * a certain tree node.
	 * 
	 * @param mapping
	 * @param viewForm
	 * @param request
	 * @param response
	 * @param errors
	 * @return
	 * @throws Exception
	 */
	private ActionForward doViewBuildings(	ActionMapping mapping,
											ViewForm viewForm,
											HttpServletRequest request,
											HttpServletResponse response,
											ActionMessages errors)
											throws Exception
	{
		// scrape form.
		int nodeId = viewForm.getNodeID();
				
		DecisionTree decisionTree = getDecisionTree(request);
		if (decisionTree == null)
		{
			// TODO: need to forward to a page that says they've logged out.
			return mapping.findForward(ERROR);
		}
		
		setCurrentNode(decisionTree.getNode(nodeId), request);
		
		logger.debug("Retrieving buildings for node " + nodeId);
		
		BuildingManager bm = decisionTree.getBuildingsForNode(nodeId);
				
		logger.debug("Retrieved " + bm.getBuildings().size() + " buildings.");
		
		//store in request
		request.setAttribute("buildingManager", bm);
		return mapping.findForward(VIEW_BUILDINGS);
	}

	/**
	 * Retrieves all the detailed data for a specific building. 
	 * 
	 * @param mapping
	 * @param viewForm
	 * @param request
	 * @param response
	 * @param errors
	 * @return
	 * @throws Exception
	 */
	private ActionForward doViewBuildingDetail(	ActionMapping mapping,
												ViewForm viewForm,
												HttpServletRequest request,
												HttpServletResponse response,
												ActionMessages errors)
												throws Exception
	{	
		//	scrape form
		BuildingManager bm = new BuildingManager();
		int buildingId = viewForm.getBuildingID();
		DecisionTree decisionTree = getDecisionTree(request);
		if (decisionTree == null)
		{
			// TODO: need to forward to a page that says they've logged out.
			return mapping.findForward(ERROR);
		}
		
		logger.debug("Retrieving data for building " + buildingId);
		
		String error = bm.loadBuilding(buildingId);
		if (error.length() > 0) 
		{
			errors.add("error", new ActionMessage("error.generic", error));
		}	
		
		//JSP will fish building out of the building mananger.
		request.setAttribute("buildingManager", bm);
			 
		return mapping.findForward(VIEW_BUILDING_DETAILS);
	}

}
