<%
/////////////////////////////////////////////////////////////////////
// FEMA Seismic Rehabilitation Cost Estimator
//
// file:	index.jsp
// author: 	Neil Chilson
// created: 7-10-2003
// revised: 
// notes:
/////////////////////////////////////////////////////////////////////
%>
<%@ page errorPage="exception.jsp" %>
<%@ page import="java.util.Vector" %>
<%@ page import="java.net.URLEncoder" %>
<%@ page import="gov.fema.util.*" %>
<%@ include file="/WEB-INF/taglib.jsp" %>
<%@ include file="header.jsp" %>

<% session.invalidate(); %>

	<h1>Seismic Rehabilitation Cost Estimator</h1>
	<h3>Welcome to SRCE!</h3>
	<p>
	The Seismic Rehabilitation Cost Estimator (SRCE) is an online program that enables calculating cost estimates for seismic rehabilitation of buildings.  The SRCE is based upon a new statistical evaluation of the cost data from approximately 2,000 seismic rehabilitation projects that were included in FEMA 156, Second Edition Typical Costs for Seismic Rehabilitation of Existing Buildings, September 1995.  No new building rehabilitation data have been added to that database in the development of SRCE.  The new statistical evaluation is based on a recently developed data mining approach known as Classification and Regression Tree (CART) analysis.
	</p>
	<h3>About CART</h3>
	<p>
	The CART analysis reduced the uncertainties in estimated costs that were found in FEMA 156, which developed cost estimation procedures using traditional probabilistic procedures.   <!-- Detailed descriptions of both the CART analysis procedures and the derivation of the cost estimating procedure are found in the report (Place link to report here, when complete)(PDF). -->
	</p>
	<p>
	<img src="img/tree.gif" align="right" valign="top" alt="Picture of a connected graph tree illustrating the text"/>
	The CART analysis forms a "upside-down tree" that starts at its "root" with all of the buildings in the database and then breaks the total inventory down into successively smaller sub-groups of buildings that have "like" cost-determining characteristics (e.g., date of construction).  Each sub-grouping is known as a "node" in the tree.  The sub-groupings at the "leaves" of the tree are known as "terminal nodes," while intermediate groupings are known as "intermediate nodes."  The uncertainty in the estimated cost is the largest at the root node of the tree, and successively more accurate for intermediate nodes closer to a terminal node. The uncertainty in the estimate cost is the smallest in the terminal nodes. 
	</p>
	<h3>How SRCE works</h3>
	<p>
	In applying SRCE, the user will seek to determine where the building that is being evaluated falls on the tree, based on its major characteristics.  Ideally, the user will wish to reach a terminal node in the tree in characterizing a building, which will occur if sufficient information is known about it.  If insufficient information is available, then the user may only be able to reach an intermediate node in the tree.  In either case, SRCE permits the user to access limited statistical data about each node, as well as the specific buildings in the FEMA 156 database that are grouped in the node.  Comparison of the characteristics of the building for which the cost estimate is sought with this information affords the user the opportunity to determine if the estimate is valid or needs further adjustment.  In other words, this allows the user to determine if the buildings in the FEMA 156 database look sufficiently "like" the building under study for the cost estimate to stand without adjustment.   
	</p>
	<p>
	Only structural costs are estimated with SRCE.  A discussion of nonstructural cost implications is provided in the report. 
	</p>
	<h3>The Two Cost Estimators</h3>
	<p>
	SRCE presents two basic cost estimation modules, based on the amount of information that is known about a building for which a seismic rehabilitation cost is sought. These modules implement two different CART analysis "trees" as described above.  
	</p>
	<p>
	First, the <B>Limited Project Information Available</B> estimation module is used when only the most basic information is available about a planned rehabilitation project (including date of construction, size, structural system, seismicity, and the building seismic performance objective) is known.  This module is primarily intended for use by those who are developing rough "programming" estimates. 
	</p>
	<p>
	Second, the <B>Detailed Project Information Available</B> estimation module can be used when more detailed information is available for a planned rehabilitation project.  This module is primarily intended for use by engineers and architects who have developed firm strategies for their projects, but who have not yet performed detailed design calculations. 
	</p>
	<p>
	FEMA encourages users to compare results from both estimation modules when sufficent data are available to enter the Detailed Project Information Available module.  The FEMA 156 database was used in deriving both modules.  The CART analysis that was performed for the Limited Project Information Available module used a more limited number of variables in defining cost than did the analysis for the Detailed Project Information Available module.  In most instances, costs estimated with the Limited Project Information Available module should be less certain than those of the Detailed Project Information Available module.  By comparing the costs, the user should gain more insight into the factors that influence the rehabilitation cost.
	
	<h3>Begin Your Estimate</h3>
	<p>
        <strong>Please choose an estimation method to proceed:</strong><br/>
		<table border=0 cellspacing=4 valign=top>
		<tr>
			<td valign ="top"><a href="initializeMethod.do?action=InitializeMethod&method=1"><b>Limited</b> Project Information Available</a></td>
			<td>This method was designed specifically for developing program budget estimates for large scale projects when the specific details of buildings are not available. Requires knowledge of the <b>date of construction</b>, <b>size</b>, <b>structural system</b>, <b>seismicity</b>, and the <b>project performance objective</b>.</td>
        </tr>
		<tr height="2px" bgcolor="#AAAAAA"><td height="2px" bgcolor="#AAAAAA" colspan="2"></td></tr>
		<tr><td valign ="top"><a href="initializeMethod.do?action=InitializeMethod&method=2"><b>Detailed</b> Project Information Available</a></td>
			<td> This method was designed for use when more comprehensive data about the specific project is available. Questions may require additional knowledge of <strong>occupancy classification</strong>; <strong>soil type</strong>; <strong>diaphragms</strong>, and <strong>project scope</strong>, along with other details.</td>
		</tr>
		</table>
    </p>
	
<%@ include file="footer.jsp" %>